%<*MF>
% Nkarta.mf
% Author:      Daniel H. Luecking
% Description: Derived from karta.mf (author and license  unknown)
% Date:        02 March 2004
% License:     Use at your own risk. If it is found that karta limits
%              derived works, nkarta will be subject to those limits.

mode_setup;
smoothing := 2; autorounding := 2;

if (not known FontSize) or (not numeric FontSize):
  numeric FontSize;
  FontSize := 15pt#;
fi
FS# := FontSize/1000;
define_pixels(FS);

% In the original, the following code occurred after each path P[n] was
% defined:
%   if (turningnumber P[n])>=0: fill else: unfill reverse fi P[n];
% This fails if turning number is 0. The following is more efficient
% and has the same effect. Moreover, it puts the repeated code in a
% macro issued only once per character.
boolean debug; debug:=false;

path P[]; numeric P;
def setP =  P[incr P] :=  enddef;

def drawthem =
if debug:                                               % debug
  pickup pencircle scaled .4pt;                         %
fi                                                      %
  for n = 1 upto P:
if debug:                                               %
     addto currentpicture doublepath (P[n] scaled FS);  %
else:                                                   %
    addto currentpicture contour (P[n] scaled FS);
fi
    cullit;                                             % debug
  endfor
enddef;
extra_beginchar:=  extra_beginchar & "P := 0;";
extra_endchar:= "drawthem;" & extra_endchar;

% I don't know what a space is needed for, but I've kept it.
beginchar (32,280*FS#,0*FS#,0*FS#);
"space";
setP (0,0) -- cycle ;
endchar;

input nkchars;

font_slant:=0;
font_normal_space:=280*FS#;
font_normal_stretch:=140*FS#;
font_normal_shrink:=93*FS#;
font_x_height:=500*FS#;
font_quad:=586*FS#;
designsize:=FontSize;
font_coding_scheme:="AppleStandard";
font_identifier:="NKarta";
end.
%</MF>
%<*MP>
% Nkarta.mp
% Author:      Daniel H. Luecking
% Description: Derived from karta.mf (author and license  unknown), this
%              is a port to MetaPost code.
% Date:        02 March 2004
% License:     Use at your own risk. If it is found that karta limits
%              derived works, nkarta will be subject to those limits.

% The MF version uses scaling FS#=FontSize/1000. The following therefore
% makes the MP results have the same size as the MF results when
% Fontsize = 15. Of course it is easy to scale the figures to any size.

pt#:=pt;
if (not known FontSize) or (not numeric FontSize):
  numeric FontSize;
  FontSize := 15pt#;
fi
FS# := FontSize/1000;
FS := FS#;

% The following is essentially the code used in the original karta.mf
% (but here made into a macro instead of being repeated over 200 times).
% This doesn't cause the same problems as that code did in karta.mf
% because Metapost doesn't have a problem with zero or negative
% turningnumber.
boolean debug; debug:=false;

path P[]; numeric P;
def setP = P[incr P] :=  enddef;

def drawthem =
if debug:                               % debug
  pickup pencircle scaled .4bp;         %
fi                                      %
  for n = 1 upto P:
if debug:                               %
    draw (P[n] scaled FS);              %
else:                                   %
    if ( turningnumber P[n] ) < 0 :
      unfill
    else :
      fill
    fi  (P[n] scaled FS);
fi                                      % debug
  endfor
enddef;

% Use same code as MF...

numeric w_, h_, d_;
def beginchar (expr num, wd, ht, dp) =
  beginfig (num); w_:=wd; h_:=ht; d_:=dp;
  P := 0;
enddef;

% ... and same bounding box as MF chars.
def endchar =
  drawthem;
  setbounds currentpicture to (0,-d_)--(w_,-d_)--(w_,h_)--(0,h_)--cycle;
  endfig;
enddef;

input nkchars;
end;
%</MP>
%<*fifteen>
% nkarta15.mf
FontSize := 15pt#;
input nkarta;
end.
%</fifteen>
%<*charsMF|charsMP>
% I've added these to avoid some error states:
turningcheck:=0;
warningcheck:=0;

% Note: the names "exclam", etc., of these figures have nothing to do
% with the actual figures. They are apparently the names of the glyph at
% that position in AppleStandard encoding. I have kept them in case they
% convey any information to anyone.
%
% All paths have been kept unchanged. But the scaling by FS has been
% moved into the drawthem macro (which is now invoked by endchar).

beginchar (33,560*FS#,650*FS#,0*FS#);
"exclam";
setP ((30,400)
.. controls (30,260) and (140,150)
.. (280,150)
.. controls (420,150) and (530,260)
.. (530,400)
.. controls (530,540) and (420,650)
.. (280,650)
.. controls (140,650) and (30,540)
.. (30,400)
-- cycle) ;
setP ((50,400)
.. controls (50,529) and (151,630)
.. (280,630)
.. controls (409,630) and (510,529)
.. (510,400)
.. controls (510,271) and (409,170)
.. (280,170)
.. controls (151,170) and (50,271)
.. (50,400)
-- cycle) ;
endchar;

beginchar (34,620*FS#,741*FS#,0*FS#);
"quotedbl";
setP ((605,230)
-- (605,571)
-- (310,741)
-- (15,571)
-- (15,230)
-- (310,60)
-- cycle) ;
setP ((585,238)
-- (310,82)
-- (35,238)
-- (35,562)
-- (310,719)
-- (585,562)
-- cycle) ;
setP ((513,255)
-- (310,659)
-- (106,255)
-- cycle) ;
setP ((140,275)
-- (310,617)
-- (481,275)
-- cycle) ;
setP ((268,389)
.. controls (268,365) and (286,347)
.. (310,347)
.. controls (334,347) and (352,365)
.. (352,389)
.. controls (352,414) and (334,432)
.. (310,432)
.. controls (286,432) and (268,414)
.. (268,389)
-- cycle) ;
endchar;

beginchar (35,560*FS#,650*FS#,0*FS#);
"numbersign";
setP ((530,150)
-- (280,650)
-- (30,150)
-- cycle) ;
setP ((65,170)
-- (280,600)
-- (495,170)
-- cycle) ;
endchar;

beginchar (36,560*FS#,683*FS#,0*FS#);
"dollar";
setP ((563,400)
-- (280,683)
-- (-3,400)
-- (280,117)
-- cycle) ;
setP ((280,147)
-- (27,400)
-- (280,653)
-- (533,400)
-- cycle) ;
endchar;

beginchar (37,560*FS#,650*FS#,0*FS#);
"percent";
setP ((424,150)
-- (569,400)
-- (424,650)
-- (136,650)
-- (-9,400)
-- (136,150)
-- cycle) ;
setP ((148,170)
-- (15,400)
-- (148,630)
-- (412,630)
-- (545,400)
-- (412,170)
-- cycle) ;
endchar;

beginchar (38,1236*FS#,916*FS#,216*FS#);
"ampersand";
setP ((1130,192)
-- (1132,194)
-- (928,330)
-- (1166,432)
-- (1164,434)
-- (876,402)
-- (1038,808)
-- (1036,810)
-- (806,542)
-- (790,682)
-- (720,584)
-- (402,916)
-- (400,914)
-- (528,534)
-- (392,558)
-- (518,424)
-- (18,536)
-- (16,534)
-- (420,318)
-- (270,232)
-- (272,230)
-- (446,242)
-- (60,-52)
-- (62,-54)
-- (524,50)
-- (532,-210)
-- (710,24)
-- (804,-88)
-- (810,68)
-- (1230,-216)
-- (1232,-214)
-- (894,224)
-- cycle) ;
endchar;

beginchar (39,620*FS#,741*FS#,0*FS#);
"quotesingle";
setP ((605,230)
-- (605,571)
-- (310,741)
-- (15,571)
-- (15,230)
-- (310,60)
-- cycle) ;
setP ((585,238)
-- (310,82)
-- (35,238)
-- (35,562)
-- (310,719)
-- (585,562)
-- cycle) ;
setP ((365,400)
.. controls (365,432) and (341,456)
.. (310,456)
.. controls (279,456) and (255,432)
.. (255,400)
.. controls (255,370) and (279,346)
.. (310,346)
.. controls (341,346) and (365,370)
.. (365,400)
-- cycle) ;
endchar;

beginchar (40,232*FS#,669*FS#,0*FS#);
"parenleft";
setP ((202,47)
-- (184,47)
-- (150,105)
-- (150,419)
-- (167,464)
-- (135,464)
-- (135,596)
.. controls (135,626) and (126,651)
.. (116,669)
.. controls (106,651) and (97,626)
.. (97,596)
-- (97,464)
-- (65,464)
-- (82,419)
-- (82,105)
-- (48,47)
-- (30,47)
-- (30,23)
-- (40,23)
-- (53,0)
-- (179,0)
-- (192,23)
-- (202,23)
-- cycle) ;
endchar;

beginchar (41,224*FS#,720*FS#,0*FS#);
"parenright";
setP ((142,545)
.. controls (142,559) and (130,565)
.. (127,565)
-- (127,658)
.. controls (127,679) and (120,699)
.. (112,720)
.. controls (104,699) and (97,679)
.. (97,658)
-- (97,565)
.. controls (94,565) and (82,559)
.. (82,545)
-- (82,389)
.. controls (79,389) and (67,383)
.. (67,369)
-- (67,68)
.. controls (67,52) and (48,38)
.. (30,34)
-- (46,0)
-- (89,0)
-- (112,27)
-- (135,0)
-- (178,0)
-- (194,34)
.. controls (176,38) and (157,52)
.. (157,68)
-- (157,369)
.. controls (157,383) and (145,389)
.. (142,389)
-- cycle) ;
endchar;

beginchar (42,1538*FS#,1037*FS#,237*FS#);
"asterisk";
setP ((1538,327)
-- (862,580)
-- (989,1035)
-- (987,1037)
-- (585,616)
-- (440,791)
-- (454,552)
-- (0,468)
-- (317,287)
-- (188,58)
-- (416,58)
-- (463,-237)
-- (661,65)
-- (918,-110)
-- (920,-108)
-- (788,150)
-- cycle) ;
endchar;

beginchar (43,600*FS#,625*FS#,0*FS#);
"plus";
setP ((485,175)
.. controls (521,175) and (550,204)
.. (550,240)
.. controls (550,275) and (521,305)
.. (485,305)
.. controls (450,305) and (420,275)
.. (420,240)
.. controls (420,204) and (450,175)
.. (485,175)
-- cycle) ;
setP ((115,175)
.. controls (151,175) and (180,204)
.. (180,240)
.. controls (180,275) and (151,305)
.. (115,305)
.. controls (80,305) and (50,275)
.. (50,240)
.. controls (50,204) and (80,175)
.. (115,175)
-- cycle) ;
setP ((300,495)
.. controls (336,495) and (365,524)
.. (365,560)
.. controls (365,595) and (336,625)
.. (300,625)
.. controls (265,625) and (235,595)
.. (235,560)
.. controls (235,524) and (265,495)
.. (300,495)
-- cycle) ;
endchar;

beginchar (44,1056*FS#,684*FS#,0*FS#);
"comma";
setP ((942,613)
.. controls (927,631) and (902,650)
.. (872,655)
-- (718,683)
.. controls (701,686) and (683,676)
.. (662,667)
-- (210,473)
.. controls (170,456) and (159,454)
.. (136,423)
-- (37,288)
.. controls (28,276) and (24,251)
.. (44,243)
-- (330,123)
.. controls (367,108) and (410,115)
.. (444,135)
-- (1004,471)
.. controls (1023,482) and (1034,502)
.. (1020,519)
-- cycle) ;
setP ((224,421)
.. controls (204,428) and (212,442)
.. (238,453)
-- (679,642)
.. controls (698,650) and (709,656)
.. (728,653)
-- (826,635)
.. controls (849,631) and (839,622)
.. (825,614)
-- (401,382)
.. controls (387,374) and (373,368)
.. (354,375)
-- cycle) ;
setP ((350,341)
.. controls (366,335) and (378,325)
.. (378,293)
-- (378,187)
.. controls (378,169) and (364,149)
.. (330,163)
-- (92,263)
.. controls (67,273) and (74,288)
.. (88,307)
-- (148,389)
.. controls (162,408) and (174,403)
.. (195,396)
-- cycle) ;
setP ((871,597)
.. controls (888,607) and (902,601)
.. (912,589)
-- (968,521)
.. controls (985,501) and (972,490)
.. (950,477)
-- (454,179)
.. controls (418,157) and (408,165)
.. (408,201)
-- (408,311)
.. controls (408,335) and (416,348)
.. (430,356)
-- cycle) ;
endchar;

beginchar (45,666*FS#,807*FS#,0*FS#);
"hyphen";
setP ((323,587)
-- (343,587)
-- (343,807)
-- (323,807)
-- cycle) ;
setP ((409,572)
-- (423,558)
-- (579,713)
-- (565,728)
-- cycle) ;
setP ((446,524)
-- (446,504)
-- (666,504)
-- (666,524)
-- cycle) ;
setP ((243,558)
-- (257,572)
-- (102,728)
-- (87,714)
-- cycle) ;
setP ((220,504)
-- (220,524)
-- (0,524)
-- (0,504)
-- cycle) ;
setP ((473,0)
-- (398,500)
.. controls (394,524) and (378,540)
.. (353,540)
-- (313,540)
.. controls (288,540) and (271,524)
.. (267,500)
-- (193,0)
-- cycle) ;
endchar;

beginchar (46,702*FS#,678*FS#,0*FS#);
"period";
setP ((372,370)
-- (589,586)
-- (608,567)
.. controls (632,542) and (654,508)
.. (662,472)
-- (695,505)
.. controls (683,540) and (652,585)
.. (613,624)
.. controls (553,684) and (444,699)
.. (395,641)
.. controls (462,658) and (521,654)
.. (550,625)
-- (567,607)
-- (351,391)
-- (135,607)
-- (152,625)
.. controls (181,654) and (240,658)
.. (307,641)
.. controls (258,699) and (149,684)
.. (89,624)
.. controls (50,585) and (19,540)
.. (7,505)
-- (40,472)
.. controls (48,508) and (70,542)
.. (94,567)
-- (113,586)
-- (330,370)
-- (66,106)
-- (87,84)
-- (351,349)
-- (615,84)
-- (637,105)
-- cycle) ;
endchar;

beginchar (47,620*FS#,650*FS#,0*FS#);
"slash";
setP ((60,400)
.. controls (60,260) and (170,150)
.. (310,150)
.. controls (450,150) and (560,260)
.. (560,400)
.. controls (560,540) and (450,650)
.. (310,650)
.. controls (170,650) and (60,540)
.. (60,400)
-- cycle) ;
setP ((312,170)
.. controls (181,170) and (80,271)
.. (80,402)
-- (308,402)
-- (308,630)
.. controls (439,630) and (540,529)
.. (540,398)
-- (312,398)
-- cycle) ;
endchar;

beginchar (48,300*FS#,404*FS#,4*FS#);
"zero";
setP ((150,-4)
.. controls (230,-5) and (291,59)
.. (291,199)
.. controls (291,339) and (230,404)
.. (150,404)
.. controls (70,404) and (9,339)
.. (9,199)
.. controls (9,59) and (70,-3)
.. (150,-4)
-- cycle) ;
setP ((150,58)
.. controls (98,58) and (71,115)
.. (71,199)
.. controls (71,284) and (98,342)
.. (150,342)
.. controls (202,342) and (229,284)
.. (229,199)
.. controls (229,115) and (202,58)
.. (150,58)
-- cycle) ;
endchar;

beginchar (49,300*FS#,400*FS#,0*FS#);
"one";
setP ((99,320)
-- (139,320)
-- (139,0)
-- (201,0)
-- (201,400)
-- (146,400)
.. controls (136,384) and (116,373)
.. (99,370)
-- cycle) ;
endchar;

beginchar (50,300*FS#,404*FS#,0*FS#);
"two";
setP ((284,0)
-- (284,62)
-- (90,62)
.. controls (94,95) and (118,123)
.. (145,142)
.. controls (197,179) and (286,203)
.. (288,292)
.. controls (289,347) and (243,404)
.. (151,404)
.. controls (79,404) and (28,353)
.. (16,299)
-- (75,285)
.. controls (88,324) and (106,342)
.. (152,342)
.. controls (192,342) and (226,322)
.. (226,289)
.. controls (226,245) and (128,207)
.. (82,169)
.. controls (38,133) and (13,75)
.. (13,0)
-- cycle) ;
endchar;

beginchar (51,300*FS#,404*FS#,4*FS#);
"three";
setP ((153,186)
.. controls (204,188) and (225,160)
.. (225,132)
.. controls (225,99) and (194,58)
.. (150,58)
.. controls (94,58) and (80,95)
.. (74,115)
-- (13,99)
.. controls (33,34) and (79,-2)
.. (146,-4)
.. controls (217,-5) and (287,58)
.. (287,134)
.. controls (287,174) and (266,207)
.. (251,217)
.. controls (266,243) and (273,262)
.. (273,297)
.. controls (273,332) and (248,404)
.. (148,404)
.. controls (82,404) and (47,353)
.. (31,327)
-- (91,302)
.. controls (104,326) and (117,342)
.. (151,342)
.. controls (180,342) and (211,319)
.. (211,291)
.. controls (211,265) and (197,248)
.. (181,248)
-- (153,248)
-- cycle) ;
endchar;

beginchar (52,300*FS#,400*FS#,0*FS#);
"four";
setP ((203,400)
-- (0,137)
-- (0,101)
-- (200,101)
-- (200,0)
-- (262,0)
-- (262,101)
-- (299,101)
-- (299,156)
-- (262,156)
-- (262,400)
-- cycle) ;
setP ((200,300)
-- (200,156)
-- (89,156)
-- cycle) ;
endchar;

beginchar (53,300*FS#,400*FS#,4*FS#);
"five";
setP ((28,198)
-- (85,180)
.. controls (98,206) and (120,217)
.. (148,217)
.. controls (186,217) and (225,194)
.. (225,148)
.. controls (225,69) and (150,58)
.. (111,58)
.. controls (83,58) and (64,65)
.. (44,76)
-- (13,18)
.. controls (34,9) and (69,-5)
.. (117,-4)
.. controls (209,-1) and (287,62)
.. (287,148)
.. controls (287,230) and (213,279)
.. (145,279)
.. controls (122,279) and (110,278)
.. (94,270)
-- (97,338)
-- (264,338)
-- (264,400)
-- (37,400)
-- cycle) ;
endchar;

beginchar (54,300*FS#,404*FS#,4*FS#);
"six";
setP ((171,404)
.. controls (65,325) and (11,211)
.. (11,126)
.. controls (11,32) and (88,-4)
.. (150,-4)
.. controls (212,-4) and (289,42)
.. (289,118)
.. controls (289,196) and (229,241)
.. (157,241)
.. controls (137,241) and (120,240)
.. (104,235)
.. controls (138,302) and (186,347)
.. (205,356)
-- cycle) ;
setP ((150,58)
.. controls (96,59) and (73,89)
.. (73,119)
.. controls (73,148) and (96,179)
.. (150,179)
.. controls (204,179) and (227,148)
.. (227,119)
.. controls (227,89) and (204,57)
.. (150,58)
-- cycle) ;
endchar;

beginchar (55,300*FS#,400*FS#,0*FS#);
"seven";
setP ((163,0)
.. controls (169,160) and (228,282)
.. (286,333)
-- (286,400)
-- (14,400)
-- (14,338)
-- (207,338)
.. controls (136,243) and (99,123)
.. (101,0)
-- cycle) ;
endchar;

beginchar (56,300*FS#,404*FS#,4*FS#);
"eight";
setP ((150,-4)
.. controls (230,-3) and (284,50)
.. (284,126)
.. controls (284,181) and (258,203)
.. (238,219)
.. controls (247,233) and (270,251)
.. (270,292)
.. controls (270,349) and (226,404)
.. (150,404)
.. controls (74,404) and (30,345)
.. (30,288)
.. controls (30,247) and (53,229)
.. (62,215)
.. controls (42,199) and (16,177)
.. (16,122)
.. controls (16,50) and (70,-5)
.. (150,-4)
-- cycle) ;
setP ((150,245)
.. controls (111,245) and (92,271)
.. (92,293)
.. controls (92,316) and (111,342)
.. (150,342)
.. controls (189,342) and (208,316)
.. (208,293)
.. controls (208,271) and (189,245)
.. (150,245)
-- cycle) ;
setP ((150,186)
.. controls (201,186) and (222,156)
.. (222,121)
.. controls (222,88) and (201,58)
.. (150,58)
.. controls (99,58) and (78,88)
.. (78,121)
.. controls (78,156) and (99,186)
.. (150,186)
-- cycle) ;
endchar;

beginchar (57,300*FS#,402*FS#,4*FS#);
"nine";
setP ((120,-4)
.. controls (228,71) and (286,183)
.. (289,268)
.. controls (292,361) and (217,400)
.. (155,402)
.. controls (93,404) and (14,361)
.. (11,286)
.. controls (9,208) and (67,160)
.. (140,158)
.. controls (160,157) and (176,158)
.. (192,163)
.. controls (156,96) and (106,54)
.. (88,46)
-- cycle) ;
setP ((150,342)
.. controls (204,342) and (227,311)
.. (227,281)
.. controls (227,251) and (204,219)
.. (150,220)
.. controls (96,221) and (73,251)
.. (73,281)
.. controls (73,311) and (96,342)
.. (150,342)
-- cycle) ;
endchar;

beginchar (58,620*FS#,650*FS#,0*FS#);
"colon";
setP ((560,150)
-- (560,650)
-- (60,650)
-- (60,150)
-- cycle) ;
setP ((80,170)
-- (80,630)
-- (540,630)
-- (540,170)
-- cycle) ;
setP ((255,400)
.. controls (255,369) and (279,345)
.. (310,345)
.. controls (341,345) and (365,369)
.. (365,400)
.. controls (365,431) and (341,455)
.. (310,455)
.. controls (279,455) and (255,431)
.. (255,400)
-- cycle) ;
endchar;

beginchar (59,620*FS#,650*FS#,0*FS#);
"semicolon";
setP ((60,400)
.. controls (60,260) and (170,150)
.. (310,150)
.. controls (450,150) and (560,260)
.. (560,400)
.. controls (560,540) and (450,650)
.. (310,650)
.. controls (170,650) and (60,540)
.. (60,400)
-- cycle) ;
setP ((80,400)
.. controls (80,529) and (181,630)
.. (310,630)
.. controls (439,630) and (540,529)
.. (540,400)
.. controls (540,271) and (439,170)
.. (310,170)
.. controls (181,170) and (80,271)
.. (80,400)
-- cycle) ;
setP ((255,400)
.. controls (255,369) and (279,345)
.. (310,345)
.. controls (341,345) and (365,369)
.. (365,400)
.. controls (365,431) and (341,455)
.. (310,455)
.. controls (279,455) and (255,431)
.. (255,400)
-- cycle) ;
endchar;

beginchar (60,700*FS#,643*FS#,0*FS#);
"less";
setP ((468,157)
-- (568,208)
-- (670,402)
-- (546,643)
-- (209,643)
-- (112,593)
-- (30,384)
-- (130,157)
-- cycle) ;
setP ((145,177)
-- (52,387)
-- (129,583)
-- (467,583)
-- (568,384)
-- (462,177)
-- cycle) ;
endchar;

beginchar (61,614*FS#,750*FS#,0*FS#);
"equal";
setP ((140,640)
-- (30,640)
-- (30,610)
-- (140,610)
-- (140,0)
-- (170,0)
-- (170,610)
-- (264,610)
-- (264,389)
-- (486,389)
-- (486,610)
-- (584,610)
-- (584,640)
-- (170,640)
-- (170,750)
-- (140,750)
-- cycle) ;
endchar;

beginchar (62,632*FS#,687*FS#,0*FS#);
"greater";
setP ((153,260)
.. controls (129,285) and (86,277)
.. (58,249)
.. controls (30,221) and (30,171)
.. (58,143)
.. controls (86,115) and (136,115)
.. (164,143)
.. controls (192,171) and (199,214)
.. (175,239)
-- (316,380)
-- (463,231)
.. controls (439,207) and (446,164)
.. (473,136)
.. controls (502,108) and (551,108)
.. (579,136)
.. controls (608,164) and (608,214)
.. (579,242)
.. controls (551,270) and (509,277)
.. (484,253)
-- (337,401)
-- (602,666)
-- (580,687)
-- (316,422)
-- (52,687)
-- (30,666)
-- (295,401)
-- cycle) ;
endchar;

beginchar (63,568*FS#,654*FS#,0*FS#);
"question";
setP ((538,146)
-- (538,654)
-- (30,654)
-- (30,146)
-- cycle) ;
setP ((518,634)
-- (518,166)
-- (50,166)
-- cycle) ;
endchar;

beginchar (64,560*FS#,600*FS#,0*FS#);
"at";
setP ((480,200)
-- (480,600)
-- (80,600)
-- (80,200)
-- cycle) ;
setP ((100,220)
-- (100,580)
-- (460,580)
-- (460,220)
-- cycle) ;
endchar;

beginchar (65,653*FS#,701*FS#,0*FS#);
"A";
setP ((342,372)
-- (463,303)
-- (469,194)
-- (498,192)
-- (493,286)
-- (579,236)
-- (593,261)
-- (506,311)
-- (590,354)
-- (573,376)
-- (477,328)
-- (357,401)
-- (477,472)
-- (573,423)
-- (590,446)
-- (506,489)
-- (593,539)
-- (579,564)
-- (493,514)
-- (498,608)
-- (469,605)
-- (463,497)
-- (342,428)
-- (342,567)
-- (432,626)
-- (420,652)
-- (342,601)
-- (342,701)
-- (312,701)
-- (312,601)
-- (234,652)
-- (223,626)
-- (312,567)
-- (312,428)
-- (192,497)
-- (186,605)
-- (156,608)
-- (161,514)
-- (75,564)
-- (60,539)
-- (148,489)
-- (63,446)
-- (81,423)
-- (176,472)
-- (297,401)
-- (176,328)
-- (81,376)
-- (63,354)
-- (148,311)
-- (60,261)
-- (75,236)
-- (161,286)
-- (156,192)
-- (186,194)
-- (192,303)
-- (312,372)
-- (312,233)
-- (223,174)
-- (234,148)
-- (312,199)
-- (312,99)
-- (342,99)
-- (342,199)
-- (420,148)
-- (432,174)
-- (342,233)
-- cycle) ;
endchar;

beginchar (66,520*FS#,750*FS#,0*FS#);
"B";
setP ((230,750)
-- (230,629)
-- (126,629)
-- (126,574)
-- (230,574)
-- (230,320)
.. controls (155,305) and (100,240)
.. (100,160)
.. controls (100,71) and (171,0)
.. (260,0)
.. controls (351,0) and (420,71)
.. (420,160)
.. controls (420,240) and (367,305)
.. (290,320)
-- (290,574)
-- (396,574)
-- (396,629)
-- (290,629)
-- (290,750)
-- cycle) ;
endchar;

beginchar (67,890*FS#,700*FS#,0*FS#);
"C";
setP ((150,50)
-- (30,50)
-- (30,0)
-- (860,0)
-- (860,50)
-- (740,50)
-- (740,608)
-- (670,608)
-- (670,420)
-- (630,420)
-- (630,524)
-- (580,614)
-- (530,524)
-- (530,265)
-- (490,265)
-- (490,700)
-- (360,700)
-- (360,360)
-- (290,360)
-- (290,200)
-- (250,200)
-- (250,490)
-- (150,490)
-- cycle) ;
endchar;

beginchar (68,760*FS#,553*FS#,0*FS#);
"D";
setP ((380,553)
-- (122,40)
-- (30,40)
-- (30,0)
-- (730,0)
-- (730,40)
-- (638,40)
-- cycle) ;
endchar;

beginchar (69,694*FS#,697*FS#,0*FS#);
"E";
setP ((347,697)
-- (260,471)
-- (30,471)
-- (206,329)
-- (141,102)
-- (347,236)
-- (553,102)
-- (478,329)
-- (664,471)
-- (435,471)
-- cycle) ;
setP ((416,451)
-- (595,451)
-- (450,340)
-- (510,157)
-- (347,267)
-- (184,157)
-- (237,340)
-- (99,451)
-- (279,451)
-- (347,634)
-- cycle) ;
endchar;

beginchar (70,689*FS#,585*FS#,9*FS#);
"F";
setP ((109,538)
.. controls (109,511) and (130,491)
.. (157,491)
.. controls (183,491) and (204,511)
.. (204,538)
.. controls (204,564) and (183,585)
.. (157,585)
.. controls (130,585) and (109,564)
.. (109,538)
-- cycle) ;
setP ((416,491)
.. controls (416,466) and (436,447)
.. (460,447)
.. controls (485,447) and (504,466)
.. (504,491)
.. controls (504,515) and (485,535)
.. (460,535)
.. controls (436,535) and (416,515)
.. (416,491)
-- cycle) ;
setP ((284,511)
.. controls (278,525) and (272,526)
.. (260,519)
-- (250,514)
.. controls (237,507) and (236,503)
.. (243,489)
-- (301,379)
.. controls (307,366) and (313,365)
.. (326,372)
-- (335,376)
.. controls (348,384) and (350,388)
.. (343,401)
-- cycle) ;
setP ((580,463)
.. controls (575,474) and (570,475)
.. (559,470)
-- (551,465)
.. controls (540,460) and (538,455)
.. (544,444)
-- (595,349)
.. controls (600,338) and (604,337)
.. (615,343)
-- (624,348)
.. controls (635,353) and (636,357)
.. (631,368)
-- cycle) ;
setP ((350,-7)
-- (382,16)
-- (292,261)
.. controls (315,284) and (315,321)
.. (302,351)
-- (239,469)
.. controls (225,495) and (205,493)
.. (189,488)
.. controls (159,481) and (146,452)
.. (144,436)
-- (136,363)
-- (30,294)
-- (36,273)
-- (53,279)
-- (150,124)
-- (125,7)
-- (173,-9)
-- (189,62)
-- (226,0)
-- (254,0)
-- (195,95)
-- (204,140)
-- (245,206)
-- cycle) ;
setP ((519,0)
-- (546,0)
-- (494,91)
-- (509,148)
-- (538,181)
-- (630,-4)
-- (659,19)
-- (585,245)
.. controls (604,264) and (612,289)
.. (593,324)
-- (540,426)
.. controls (527,449) and (507,450)
.. (494,443)
.. controls (471,431) and (452,422)
.. (448,399)
-- (442,349)
-- (340,271)
-- (350,252)
-- (368,261)
-- (452,117)
-- (425,11)
-- (469,-4)
-- (486,57)
-- cycle) ;
setP ((207,290)
.. controls (188,269) and (170,222)
.. (157,157)
-- (75,287)
-- (164,320)
-- (175,355)
-- cycle) ;
setP ((509,271)
-- (470,194)
-- (459,152)
-- (390,273)
-- (458,310)
-- (477,349)
-- cycle) ;
endchar;

beginchar (71,550*FS#,358*FS#,0*FS#);
"G";
setP ((500,0)
-- (500,30)
-- (428,30)
-- (428,226)
-- (500,207)
-- (500,237)
-- (50,358)
-- (50,328)
-- (122,309)
-- (122,30)
-- (50,30)
-- (50,0)
-- cycle) ;
endchar;

beginchar (72,1026*FS#,524*FS#,0*FS#);
"H";
setP ((150,309)
.. controls (146,310) and (141,307)
.. (140,303)
-- (138,292)
.. controls (137,287) and (140,283)
.. (144,282)
-- (412,225)
.. controls (416,224) and (421,227)
.. (422,231)
-- (424,243)
.. controls (425,247) and (421,252)
.. (418,253)
-- cycle) ;
setP ((641,206)
.. controls (637,207) and (632,204)
.. (631,200)
-- (629,189)
.. controls (628,184) and (631,180)
.. (635,179)
-- (903,122)
.. controls (907,121) and (912,124)
.. (913,128)
-- (915,140)
.. controls (916,144) and (912,149)
.. (909,150)
-- cycle) ;
setP ((523,292)
.. controls (479,292) and (450,263)
.. (450,219)
.. controls (450,175) and (479,146)
.. (523,146)
.. controls (567,146) and (596,175)
.. (596,219)
.. controls (596,263) and (567,292)
.. (523,292)
-- cycle) ;
setP ((996,24)
.. controls (996,30) and (990,35)
.. (984,36)
-- (71,227)
.. controls (40,233) and (30,224)
.. (30,206)
-- (30,0)
-- (460,0)
.. controls (482,0) and (507,14)
.. (520,35)
.. controls (533,14) and (558,0)
.. (580,0)
.. controls (602,0) and (627,14)
.. (640,35)
.. controls (653,14) and (678,0)
.. (700,0)
.. controls (722,0) and (747,14)
.. (760,35)
.. controls (773,14) and (798,0)
.. (820,0)
.. controls (842,0) and (867,14)
.. (880,35)
.. controls (893,14) and (918,0)
.. (940,0)
-- (996,0)
-- cycle) ;
setP ((427,504)
-- (427,524)
-- (414,524)
-- (326,445)
-- (120,488)
-- (114,456)
.. controls (103,397) and (187,337)
.. (245,325)
-- (442,284)
.. controls (462,280) and (484,320)
.. (544,307)
.. controls (602,294) and (607,251)
.. (626,246)
-- (892,190)
.. controls (912,186) and (925,199)
.. (928,217)
-- (940,289)
.. controls (943,305) and (933,317)
.. (915,321)
-- (354,439)
-- cycle) ;
setP ((523,269)
.. controls (553,269) and (573,249)
.. (573,219)
.. controls (573,189) and (553,169)
.. (523,169)
.. controls (493,169) and (473,189)
.. (473,219)
.. controls (473,249) and (493,269)
.. (523,269)
-- cycle) ;
endchar;

beginchar (73,946*FS#,857*FS#,58*FS#);
"I";
setP ((702,-58)
.. controls (736,-58) and (742,-50)
.. (753,-18)
-- (931,539)
.. controls (939,563) and (946,593)
.. (946,619)
.. controls (946,659) and (909,700)
.. (867,718)
-- (581,837)
.. controls (553,849) and (513,857)
.. (473,857)
.. controls (433,857) and (393,849)
.. (366,837)
-- (79,718)
.. controls (38,700) and (0,659)
.. (0,619)
.. controls (0,593) and (7,563)
.. (15,539)
-- (193,-18)
.. controls (205,-50) and (210,-58)
.. (245,-58)
-- cycle) ;
setP ((260,-28)
.. controls (227,-28) and (223,-21)
.. (216,0)
-- (45,530)
.. controls (38,552) and (30,580)
.. (30,605)
.. controls (30,642) and (67,680)
.. (105,697)
-- (373,808)
.. controls (398,820) and (436,827)
.. (473,827)
.. controls (510,827) and (548,820)
.. (574,808)
-- (841,697)
.. controls (880,680) and (916,642)
.. (916,605)
.. controls (916,580) and (908,552)
.. (901,530)
-- (731,0)
.. controls (724,-21) and (719,-28)
.. (687,-28)
-- cycle) ;
endchar;

beginchar (74,732*FS#,697*FS#,0*FS#);
"J";
setP ((365,104)
-- (367,104)
-- (377,214)
-- (391,190)
-- (487,197)
-- (487,243)
.. controls (487,251) and (484,259)
.. (479,260)
-- (381,269)
-- (400,453)
-- (550,453)
-- (702,484)
-- (702,531)
.. controls (702,540) and (697,543)
.. (689,544)
-- (546,556)
-- (405,556)
.. controls (402,612) and (400,650)
.. (398,655)
.. controls (394,660) and (384,662)
.. (379,662)
.. controls (374,677) and (372,697)
.. (366,697)
.. controls (360,697) and (358,677)
.. (353,662)
.. controls (348,662) and (338,660)
.. (335,655)
.. controls (332,650) and (330,612)
.. (327,556)
-- (186,556)
-- (43,544)
.. controls (35,543) and (30,540)
.. (30,531)
-- (30,484)
-- (182,453)
-- (332,453)
-- (351,269)
-- (253,260)
.. controls (248,259) and (245,251)
.. (245,243)
-- (245,197)
-- (341,190)
-- (355,214)
-- cycle) ;
endchar;

beginchar (75,357*FS#,600*FS#,0*FS#);
"K";
setP ((221,600)
-- (50,600)
-- (136,300)
-- (50,0)
-- (221,0)
-- (307,300)
-- cycle) ;
endchar;

beginchar (76,1020*FS#,810*FS#,10*FS#);
"L";
setP ((60,810)
.. controls (30,810) and (0,780)
.. (0,750)
-- (0,50)
.. controls (0,20) and (30,-8)
.. (60,-10)
-- (960,-10)
.. controls (990,-10) and (1020,20)
.. (1020,50)
-- (1020,750)
.. controls (1020,780) and (990,810)
.. (960,810)
-- cycle) ;
setP ((941,780)
.. controls (969,780) and (990,760)
.. (990,732)
-- (990,68)
.. controls (990,40) and (969,20)
.. (941,20)
-- (78,20)
.. controls (50,22) and (30,40)
.. (30,68)
-- (30,732)
.. controls (30,760) and (50,780)
.. (78,780)
-- cycle) ;
endchar;

beginchar (77,586*FS#,890*FS#,52*FS#);
"M";
setP ((30,-52)
-- (61,-52)
-- (278,311)
-- (278,206)
.. controls (264,206) and (256,194)
.. (256,174)
-- (256,-52)
-- (330,-52)
-- (330,174)
.. controls (330,191) and (322,206)
.. (308,206)
-- (308,311)
-- (525,-52)
-- (556,-52)
-- (402,850)
-- (308,850)
-- (308,890)
-- (278,890)
-- (278,850)
-- (184,850)
-- cycle) ;
setP ((478,317)
-- (538,-32)
-- (533,-32)
-- (324,317)
-- cycle) ;
setP ((308,337)
-- (308,632)
-- (311,632)
-- (466,337)
-- cycle) ;
setP ((120,337)
-- (275,632)
-- (278,632)
-- (278,337)
-- cycle) ;
setP ((424,632)
-- (468,374)
-- (466,374)
-- (330,632)
-- cycle) ;
setP ((256,632)
-- (120,374)
-- (118,374)
-- (162,632)
-- cycle) ;
setP ((308,652)
-- (308,830)
-- (312,830)
-- (402,652)
-- cycle) ;
setP ((184,652)
-- (274,830)
-- (278,830)
-- (278,652)
-- cycle) ;
setP ((390,830)
-- (418,668)
-- (413,668)
-- (330,830)
-- cycle) ;
setP ((256,830)
-- (173,668)
-- (168,668)
-- (196,830)
-- cycle) ;
setP ((261,317)
-- (53,-32)
-- (48,-32)
-- (108,317)
-- cycle) ;
endchar;

beginchar (78,642*FS#,554*FS#,0*FS#);
"N";
setP ((459,511)
.. controls (414,539) and (367,554)
.. (317,554)
.. controls (267,554) and (220,539)
.. (175,511)
-- (276,337)
.. controls (292,345) and (302,351)
.. (317,351)
.. controls (332,351) and (350,345)
.. (366,337)
-- cycle) ;
setP ((414,251)
.. controls (413,233) and (410,214)
.. (403,201)
.. controls (396,187) and (386,181)
.. (371,171)
-- (478,0)
.. controls (524,27) and (559,61)
.. (582,105)
.. controls (606,150) and (615,198)
.. (611,251)
-- cycle) ;
setP ((31,251)
.. controls (27,198) and (36,150)
.. (60,105)
.. controls (83,61) and (118,27)
.. (164,0)
-- (271,171)
.. controls (256,181) and (246,187)
.. (239,201)
.. controls (232,214) and (229,233)
.. (228,251)
-- cycle) ;
setP ((273,254)
.. controls (273,227) and (294,206)
.. (321,206)
.. controls (348,206) and (369,227)
.. (369,254)
.. controls (369,281) and (348,302)
.. (321,302)
.. controls (294,302) and (273,281)
.. (273,254)
-- cycle) ;
endchar;

beginchar (79,1442*FS#,799*FS#,0*FS#);
"O";
setP ((0,411)
.. controls (0,194) and (311,22)
.. (721,22)
.. controls (1125,22) and (1442,194)
.. (1442,411)
.. controls (1442,628) and (1125,799)
.. (721,799)
.. controls (318,799) and (0,628)
.. (0,411)
-- cycle) ;
setP ((30,411)
.. controls (30,611) and (335,769)
.. (721,769)
.. controls (1108,769) and (1412,611)
.. (1412,411)
.. controls (1412,211) and (1108,52)
.. (721,52)
.. controls (328,52) and (30,211)
.. (30,411)
-- cycle) ;
endchar;

beginchar (80,1154*FS#,899*FS#,100*FS#);
"P";
setP ((52,899)
.. controls (0,899) and (-13,876)
.. (12,830)
-- (537,-66)
.. controls (563,-111) and (591,-111)
.. (617,-66)
-- (1142,830)
.. controls (1167,876) and (1154,899)
.. (1102,899)
-- cycle) ;
setP ((1065,869)
.. controls (1116,869) and (1125,858)
.. (1102,819)
-- (606,-28)
.. controls (584,-66) and (570,-66)
.. (548,-28)
-- (52,819)
.. controls (29,858) and (38,869)
.. (89,869)
-- cycle) ;
endchar;

beginchar (81,676*FS#,750*FS#,0*FS#);
"Q";
setP ((95,80)
-- (149,80)
-- (149,452)
-- (95,452)
-- cycle) ;
setP ((203,80)
-- (257,80)
-- (257,452)
-- (203,452)
-- cycle) ;
setP ((311,80)
-- (365,80)
-- (365,452)
-- (311,452)
-- cycle) ;
setP ((419,80)
-- (473,80)
-- (473,452)
-- (419,452)
-- cycle) ;
setP ((527,80)
-- (581,80)
-- (581,452)
-- (527,452)
-- cycle) ;
setP ((338,750)
-- (30,482)
-- (646,482)
-- cycle) ;
setP ((626,0)
-- (626,50)
-- (50,50)
-- (50,0)
-- cycle) ;
endchar;

beginchar (82,695*FS#,717*FS#,0*FS#);
"R";
setP ((30,400)
.. controls (30,223) and (170,83)
.. (347,83)
.. controls (524,83) and (665,223)
.. (665,400)
.. controls (665,577) and (524,717)
.. (347,717)
.. controls (170,717) and (30,577)
.. (30,400)
-- cycle) ;
setP ((60,400)
.. controls (60,561) and (187,687)
.. (348,687)
.. controls (508,687) and (635,561)
.. (635,400)
.. controls (635,239) and (508,113)
.. (348,113)
.. controls (187,113) and (60,239)
.. (60,400)
-- cycle) ;
setP reverse ((410,491)
-- (620,491)
-- (450,364)
-- (516,164)
-- (348,288)
-- (179,164)
-- (246,364)
-- (76,491)
-- (285,491)
-- (348,687)
-- cycle) ;
endchar;

beginchar (83,963*FS#,713*FS#,0*FS#);
"S";
setP ((677,505)
.. controls (673,538) and (762,498)
.. (819,500)
.. controls (871,504) and (876,544)
.. (933,557)
-- (933,560)
.. controls (832,569) and (706,704)
.. (567,704)
.. controls (507,704) and (410,633)
.. (341,633)
.. controls (278,633) and (226,713)
.. (187,713)
.. controls (122,713) and (108,617)
.. (38,628)
.. controls (27,629) and (27,613)
.. (38,612)
.. controls (99,600) and (75,602)
.. (125,600)
.. controls (165,600) and (194,633)
.. (215,633)
.. controls (248,633) and (276,609)
.. (302,583)
.. controls (342,543) and (403,522)
.. (403,494)
-- (403,258)
.. controls (403,204) and (380,140)
.. (347,87)
.. controls (410,117) and (524,187)
.. (550,266)
.. controls (567,316) and (642,448)
.. (671,448)
.. controls (761,448) and (722,431)
.. (772,431)
.. controls (788,431) and (803,429)
.. (819,426)
.. controls (811,436) and (796,440)
.. (784,442)
.. controls (781,455) and (779,465)
.. (767,465)
.. controls (745,465) and (712,460)
.. (680,469)
-- cycle) ;
fill (P1 scaled FS);
endchar;

beginchar (84,695*FS#,717*FS#,0*FS#);
"T";
setP ((30,400)
.. controls (30,223) and (170,83)
.. (347,83)
.. controls (524,83) and (665,223)
.. (665,400)
.. controls (665,577) and (524,717)
.. (347,717)
.. controls (170,717) and (30,577)
.. (30,400)
-- cycle) ;
setP ((60,400)
.. controls (60,561) and (187,687)
.. (348,687)
.. controls (508,687) and (635,561)
.. (635,400)
.. controls (635,239) and (508,113)
.. (348,113)
.. controls (187,113) and (60,239)
.. (60,400)
-- cycle) ;
setP ((531,400)
.. controls (531,508) and (456,584)
.. (348,584)
.. controls (240,584) and (164,508)
.. (164,400)
.. controls (164,292) and (240,216)
.. (348,216)
.. controls (456,216) and (531,292)
.. (531,400)
-- cycle) ;
setP ((501,400)
.. controls (501,309) and (438,246)
.. (348,246)
.. controls (257,246) and (194,309)
.. (194,400)
.. controls (194,491) and (257,554)
.. (348,554)
.. controls (438,554) and (501,491)
.. (501,400)
-- cycle) ;
endchar;

beginchar (85,1063*FS#,921*FS#,122*FS#);
"U";
setP ((30,748)
.. controls (58,736) and (97,664)
.. (97,608)
.. controls (97,545) and (0,460)
.. (0,299)
.. controls (0,83) and (151,-88)
.. (265,-88)
.. controls (315,-88) and (344,-79)
.. (367,-69)
.. controls (391,-60) and (409,-50)
.. (425,-50)
.. controls (456,-50) and (499,-84)
.. (531,-122)
.. controls (563,-84) and (607,-50)
.. (638,-50)
.. controls (654,-50) and (672,-60)
.. (696,-69)
.. controls (719,-79) and (747,-88)
.. (798,-88)
.. controls (912,-88) and (1063,83)
.. (1063,299)
.. controls (1063,460) and (966,545)
.. (966,608)
.. controls (967,664) and (1006,736)
.. (1034,748)
-- (845,921)
.. controls (793,862) and (741,824)
.. (689,824)
.. controls (637,824) and (555,862)
.. (531,921)
.. controls (509,862) and (427,824)
.. (375,824)
.. controls (323,824) and (271,862)
.. (218,921)
-- cycle) ;
setP ((936,608)
.. controls (951,511) and (1033,452)
.. (1033,299)
.. controls (1033,124) and (911,-58)
.. (795,-58)
.. controls (764,-58) and (733,-55)
.. (710,-46)
.. controls (687,-37) and (670,-20)
.. (632,-20)
.. controls (595,-17) and (562,-53)
.. (531,-83)
.. controls (500,-53) and (467,-17)
.. (430,-20)
.. controls (392,-20) and (375,-37)
.. (352,-46)
.. controls (329,-55) and (298,-58)
.. (267,-58)
.. controls (151,-58) and (29,124)
.. (29,299)
.. controls (29,452) and (111,511)
.. (126,608)
-- cycle) ;
endchar;

beginchar (86,520*FS#,750*FS#,0*FS#);
"V";
setP ((420,0)
-- (420,320)
-- (275,320)
-- (275,499)
-- (420,625)
-- (245,750)
-- (245,320)
-- (100,320)
-- (100,0)
-- cycle) ;
endchar;

beginchar (87,968*FS#,848*FS#,48*FS#);
"W";
setP ((499,-48)
-- (499,134)
.. controls (499,158) and (512,180)
.. (528,180)
.. controls (554,180) and (659,145)
.. (711,137)
.. controls (704,158) and (700,186)
.. (700,202)
.. controls (700,226) and (856,332)
.. (938,394)
.. controls (896,396) and (846,396)
.. (846,428)
.. controls (846,472) and (872,520)
.. (890,554)
.. controls (824,530) and (778,518)
.. (746,518)
.. controls (730,518) and (734,583)
.. (739,607)
-- (737,609)
.. controls (678,529) and (624,440)
.. (596,440)
.. controls (564,440) and (577,482)
.. (584,513)
.. controls (603,592) and (628,676)
.. (645,750)
.. controls (612,722) and (586,700)
.. (566,700)
.. controls (534,700) and (500,780)
.. (485,848)
-- (483,848)
.. controls (468,780) and (434,700)
.. (402,700)
.. controls (382,700) and (356,722)
.. (323,750)
.. controls (340,676) and (365,592)
.. (384,513)
.. controls (391,482) and (404,440)
.. (372,440)
.. controls (344,440) and (290,529)
.. (231,609)
-- (229,607)
.. controls (234,583) and (238,518)
.. (222,518)
.. controls (190,518) and (144,530)
.. (78,554)
.. controls (96,520) and (122,472)
.. (122,428)
.. controls (122,396) and (72,396)
.. (30,394)
.. controls (112,332) and (268,226)
.. (268,202)
.. controls (268,186) and (264,158)
.. (257,137)
.. controls (309,145) and (414,180)
.. (440,180)
.. controls (456,180) and (469,158)
.. (469,134)
-- (469,-48)
-- cycle) ;
endchar;

beginchar (88,698*FS#,700*FS#,0*FS#);
"X";
setP ((170,428)
.. controls (114,412) and (30,358)
.. (30,228)
.. controls (30,105) and (128,0)
.. (256,0)
.. controls (372,0) and (450,62)
.. (489,117)
-- (469,175)
.. controls (428,100) and (353,50)
.. (258,50)
.. controls (164,50) and (83,131)
.. (83,227)
.. controls (83,321) and (132,364)
.. (172,378)
-- cycle) ;
setP ((260,440)
-- (256,566)
.. controls (282,566) and (318,593)
.. (318,633)
.. controls (318,680) and (284,700)
.. (244,700)
.. controls (200,700) and (175,666)
.. (176,633)
.. controls (177,612) and (192,604)
.. (193,582)
-- (203,290)
-- (460,290)
-- (538,66)
-- (672,113)
-- (655,163)
-- (576,135)
-- (505,340)
-- (264,340)
-- (262,390)
-- (433,390)
-- (431,440)
-- cycle) ;
endchar;

beginchar (89,700*FS#,800*FS#,0*FS#);
"Y";
setP ((0,800)
-- (0,300)
.. controls (0,110) and (180,0)
.. (350,0)
.. controls (520,0) and (700,110)
.. (700,300)
-- (700,800)
-- cycle) ;
setP ((291,653)
.. controls (315,653) and (338,719)
.. (348,775)
-- (350,775)
.. controls (361,719) and (384,653)
.. (407,653)
.. controls (421,653) and (439,671)
.. (462,695)
.. controls (451,634) and (434,566)
.. (420,501)
.. controls (415,476) and (406,441)
.. (429,441)
.. controls (448,441) and (486,514)
.. (525,579)
-- (527,577)
-- (528,578)
.. controls (525,558) and (522,505)
.. (534,505)
.. controls (556,505) and (588,514)
.. (634,535)
.. controls (622,507) and (603,467)
.. (603,431)
.. controls (603,419) and (612,412)
.. (625,408)
.. controls (637,405) and (654,405)
.. (668,403)
.. controls (610,353) and (501,266)
.. (501,246)
.. controls (501,233) and (504,211)
.. (509,193)
.. controls (472,200) and (409,228)
.. (390,228)
.. controls (378,228) and (370,211)
.. (370,190)
-- (370,42)
-- (329,42)
-- (329,190)
.. controls (329,211) and (321,228)
.. (309,228)
.. controls (291,228) and (227,200)
.. (190,193)
.. controls (195,211) and (198,233)
.. (198,246)
.. controls (198,266) and (89,353)
.. (31,403)
.. controls (61,406) and (96,406)
.. (96,431)
.. controls (96,467) and (78,507)
.. (65,535)
.. controls (111,514) and (143,505)
.. (166,505)
.. controls (177,505) and (174,558)
.. (171,576)
-- (173,578)
-- (172,579)
.. controls (214,514) and (251,441)
.. (271,441)
.. controls (294,441) and (284,476)
.. (279,501)
.. controls (267,566) and (249,634)
.. (237,695)
.. controls (260,671) and (278,653)
.. (291,653)
-- cycle) ;
endchar;

beginchar (90,302*FS#,700*FS#,0*FS#);
"Z";
setP ((206,503)
-- (253,503)
.. controls (266,503) and (272,512)
.. (272,528)
-- (272,675)
.. controls (272,691) and (266,700)
.. (253,700)
-- (206,700)
-- cycle) ;
setP ((182,197)
.. controls (168,197) and (153,203)
.. (146,228)
.. controls (139,252) and (137,283)
.. (137,350)
.. controls (137,417) and (139,448)
.. (146,472)
.. controls (153,497) and (168,503)
.. (182,503)
-- (182,700)
.. controls (142,692) and (112,655)
.. (76,598)
.. controls (34,532) and (30,412)
.. (30,350)
.. controls (30,288) and (34,168)
.. (76,102)
.. controls (112,45) and (142,8)
.. (182,0)
-- cycle) ;
setP ((203,0)
-- (250,0)
.. controls (263,0) and (269,9)
.. (269,25)
-- (269,172)
.. controls (269,188) and (263,197)
.. (250,197)
-- (203,197)
-- cycle) ;
endchar;

beginchar (91,575*FS#,1100*FS#,100*FS#);
"bracketleft";
setP ((30,-98)
-- (32,-100)
-- (287,206)
-- (543,-100)
-- (545,-98)
-- (287,788)
-- cycle) ;
setP ((345,1088)
-- (379,1082)
-- (379,908)
-- (206,1100)
-- (141,1100)
-- (141,1088)
-- (173,1082)
-- (173,872)
-- (141,866)
-- (141,854)
-- (232,854)
-- (232,866)
-- (197,872)
-- (197,1056)
.. controls (236,1014) and (359,878)
.. (383,852)
-- (403,852)
-- (403,1082)
-- (434,1088)
-- (434,1100)
-- (345,1100)
-- cycle) ;
setP ((98,26)
-- (96,28)
-- (285,691)
-- (287,691)
-- (287,253)
-- cycle) ;
endchar;

beginchar (92,1871*FS#,1394*FS#,395*FS#);
"backslash";
setP ((927,772)
.. controls (846,757) and (736,671)
.. (722,566)
-- (436,503)
-- (436,501)
-- (722,438)
.. controls (736,333) and (846,247)
.. (927,233)
-- (990,-53)
-- (992,-53)
-- (1055,233)
.. controls (1136,247) and (1246,333)
.. (1260,438)
-- (1546,501)
-- (1546,503)
-- (1260,566)
.. controls (1246,671) and (1136,757)
.. (1055,771)
-- (992,1057)
-- (990,1057)
-- cycle) ;
setP ((1037,1394)
-- (1037,1384)
-- (1063,1379)
-- (1063,1240)
-- (929,1394)
-- (874,1394)
-- (874,1384)
-- (899,1379)
-- (899,1211)
-- (874,1207)
-- (874,1197)
-- (947,1197)
-- (947,1207)
-- (919,1211)
-- (919,1359)
.. controls (950,1325) and (1045,1216)
.. (1064,1195)
-- (1083,1195)
-- (1083,1379)
-- (1108,1384)
-- (1108,1394)
-- cycle) ;
setP ((1039,-194)
.. controls (1025,-193) and (1011,-188)
.. (997,-188)
.. controls (958,-188) and (932,-212)
.. (932,-242)
.. controls (932,-314) and (1027,-299)
.. (1027,-347)
.. controls (1027,-372) and (1011,-384)
.. (987,-384)
.. controls (975,-384) and (953,-378)
.. (947,-366)
.. controls (943,-358) and (939,-346)
.. (937,-330)
-- (928,-333)
-- (931,-380)
.. controls (945,-390) and (970,-395)
.. (989,-395)
.. controls (1031,-395) and (1057,-369)
.. (1057,-334)
.. controls (1057,-276) and (962,-286)
.. (962,-235)
.. controls (962,-214) and (974,-202)
.. (995,-202)
.. controls (1020,-202) and (1029,-218)
.. (1034,-238)
-- (1043,-238)
-- cycle) ;
setP ((138,603)
-- (138,593)
-- (165,588)
.. controls (163,578) and (159,567)
.. (155,556)
-- (120,447)
-- (80,588)
-- (107,593)
-- (107,603)
-- (30,603)
-- (30,593)
-- (52,588)
-- (105,401)
-- (120,401)
-- (170,549)
-- (217,401)
-- (232,401)
-- (292,588)
-- (311,593)
-- (311,603)
-- (246,603)
-- (246,593)
-- (275,588)
-- (231,448)
-- (196,558)
.. controls (193,568) and (190,578)
.. (187,588)
-- (215,593)
-- (215,603)
-- cycle) ;
setP ((1793,500)
-- (1798,478)
-- (1807,478)
.. controls (1805,494) and (1805,520)
.. (1807,535)
-- (1798,535)
-- (1793,514)
-- (1743,514)
-- (1743,585)
-- (1803,585)
-- (1811,559)
-- (1820,559)
-- (1816,603)
-- (1686,603)
-- (1686,593)
-- (1713,588)
-- (1713,420)
-- (1686,415)
-- (1686,406)
-- (1829,406)
-- (1841,454)
-- (1830,454)
-- (1819,424)
-- (1743,424)
-- (1743,500)
-- cycle) ;
setP ((746,502)
.. controls (746,639) and (834,747)
.. (991,747)
.. controls (1148,747) and (1236,639)
.. (1236,502)
.. controls (1236,365) and (1148,257)
.. (991,257)
.. controls (834,257) and (746,365)
.. (746,502)
-- cycle) ;
setP ((943,772)
-- (989,989)
-- (991,989)
-- (991,772)
-- cycle) ;
setP ((722,454)
-- (505,500)
-- (505,502)
-- (722,502)
-- cycle) ;
setP ((1039,233)
-- (993,16)
-- (991,16)
-- (991,233)
-- cycle) ;
setP ((1260,550)
-- (1478,504)
-- (1478,502)
-- (1260,502)
-- cycle) ;
endchar;

beginchar (93,352*FS#,1662*FS#,662*FS#);
"bracketright";
setP ((234,1650)
-- (268,1644)
-- (268,1470)
-- (95,1662)
-- (30,1662)
-- (30,1650)
-- (62,1644)
-- (62,1434)
-- (30,1428)
-- (30,1416)
-- (121,1416)
-- (121,1428)
-- (86,1434)
-- (86,1618)
.. controls (125,1576) and (248,1440)
.. (272,1414)
-- (292,1414)
-- (292,1644)
-- (323,1650)
-- (323,1662)
-- (234,1662)
-- cycle) ;
setP ((182,278)
.. controls (241,281) and (283,330)
.. (283,381)
.. controls (283,432) and (241,486)
.. (190,484)
-- (190,614)
-- (270,576)
-- (178,1338)
-- (175,1338)
-- (82,576)
-- (163,614)
-- (163,484)
.. controls (112,484) and (69,432)
.. (69,381)
.. controls (69,330) and (112,278)
.. (171,278)
-- (69,-662)
-- (176,-611)
-- (283,-662)
-- cycle) ;
setP ((270,380)
.. controls (265,335) and (230,286)
.. (178,291)
-- (178,380)
-- cycle) ;
setP ((176,1228)
-- (179,1228)
-- (253,602)
-- (176,636)
-- cycle) ;
setP ((85,-640)
-- (174,196)
-- (176,196)
-- (176,-597)
-- cycle) ;
setP ((175,382)
-- (82,382)
.. controls (82,439) and (123,468)
.. (175,471)
-- cycle) ;
endchar;

beginchar (94,1538*FS#,1037*FS#,237*FS#);
"asciicircum";
setP ((1538,327)
-- (862,580)
-- (989,1035)
-- (987,1037)
-- (585,616)
-- (440,791)
-- (454,552)
-- (0,468)
-- (317,287)
-- (188,58)
-- (416,58)
-- (463,-237)
-- (661,65)
-- (918,-110)
-- (920,-108)
-- (788,150)
-- cycle) ;
setP ((759,164)
-- (867,-50)
-- (865,-52)
-- (656,92)
-- (474,-184)
-- (435,78)
-- (223,78)
-- (343,294)
-- (61,460)
-- (475,536)
-- (462,736)
-- (582,584)
-- (948,967)
-- (949,970)
-- (951,968)
-- (837,567)
-- (1472,332)
-- cycle) ;
endchar;

beginchar (95,666*FS#,694*FS#,0*FS#);
"underscore";
setP ((475,0)
-- (405,472)
-- (602,357)
-- (612,375)
-- (401,498)
.. controls (397,520) and (393,540)
.. (382,540)
-- (382,542)
-- (612,672)
-- (602,690)
-- (342,540)
-- (329,540)
-- (64,694)
-- (54,676)
-- (288,540)
.. controls (277,540) and (273,520)
.. (269,498)
-- (54,374)
-- (64,358)
-- (265,473)
-- (195,0)
-- cycle) ;
endchar;

beginchar (96,458*FS#,691*FS#,0*FS#);
"grave";
setP ((378,333)
-- (410,333)
-- (410,506)
-- (260,575)
.. controls (237,585) and (226,586)
.. (210,579)
.. controls (194,572) and (173,563)
.. (168,540)
-- (157,485)
.. controls (146,485) and (144,462)
.. (136,427)
-- (30,365)
-- (42,333)
-- (164,384)
-- (198,446)
-- (242,358)
-- (168,232)
-- (113,18)
-- (173,0)
-- (219,177)
-- (274,255)
-- (386,0)
-- (428,29)
-- (332,324)
.. controls (340,346) and (345,369)
.. (337,397)
-- (313,483)
-- (364,480)
-- cycle) ;
setP ((129,639)
.. controls (129,610) and (152,588)
.. (181,588)
.. controls (208,588) and (231,610)
.. (231,639)
.. controls (231,668) and (208,691)
.. (181,691)
.. controls (152,691) and (129,668)
.. (129,639)
-- cycle) ;
endchar;

beginchar (97,754*FS#,464*FS#,6*FS#);
"a";
setP ((97,275)
.. controls (97,249) and (117,230)
.. (142,230)
.. controls (166,230) and (187,249)
.. (187,275)
.. controls (187,300) and (166,320)
.. (142,320)
.. controls (117,320) and (97,300)
.. (97,275)
-- cycle) ;
setP ((460,406)
.. controls (445,419) and (420,439)
.. (387,439)
.. controls (358,439) and (330,429)
.. (312,417)
.. controls (299,410) and (234,363)
.. (213,340)
.. controls (206,331) and (196,317)
.. (196,309)
.. controls (196,298) and (204,284)
.. (220,280)
.. controls (238,275) and (275,272)
.. (275,272)
-- (278,258)
-- (218,212)
-- (236,195)
-- (296,226)
-- (448,124)
-- (129,13)
.. controls (119,10) and (108,6)
.. (91,6)
.. controls (73,6) and (54,20)
.. (48,28)
.. controls (36,40) and (25,32)
.. (32,23)
.. controls (39,14) and (54,-6)
.. (86,-6)
.. controls (116,-6) and (129,-1)
.. (144,3)
-- (724,206)
-- (720,219)
-- (493,140)
-- (383,237)
-- (446,298)
.. controls (471,320) and (478,342)
.. (478,364)
.. controls (478,378) and (470,393)
.. (467,398)
-- (512,434)
-- (527,416)
-- (534,421)
-- (519,440)
-- (533,450)
-- (527,458)
-- (514,448)
-- (500,464)
-- (492,460)
-- (507,442)
-- cycle) ;
endchar;

beginchar (98,520*FS#,750*FS#,0*FS#);
"b";
setP ((420,0)
-- (420,320)
-- (290,320)
-- (290,574)
-- (396,574)
-- (396,629)
-- (290,629)
-- (290,750)
-- (230,750)
-- (230,629)
-- (124,629)
-- (124,574)
-- (230,574)
-- (230,320)
-- (100,320)
-- (100,0)
-- cycle) ;
endchar;

beginchar (99,740*FS#,680*FS#,0*FS#);
"c";
setP ((30,340)
.. controls (30,150) and (180,0)
.. (370,0)
.. controls (560,0) and (710,150)
.. (710,340)
.. controls (710,530) and (560,680)
.. (370,680)
.. controls (180,680) and (30,530)
.. (30,340)
-- cycle) ;
setP ((355,499)
.. controls (322,501) and (286,509)
.. (253,521)
.. controls (272,567) and (297,609)
.. (324,646)
.. controls (335,648) and (345,649)
.. (355,649)
-- cycle) ;
setP ((355,355)
-- (213,355)
.. controls (215,402) and (226,449)
.. (244,496)
.. controls (282,480) and (321,470)
.. (355,468)
-- cycle) ;
setP ((355,325)
-- (355,212)
.. controls (321,210) and (282,200)
.. (244,184)
.. controls (226,232) and (215,280)
.. (213,325)
-- cycle) ;
setP ((355,31)
.. controls (345,31) and (335,32)
.. (324,34)
.. controls (296,71) and (272,115)
.. (254,160)
.. controls (288,172) and (323,179)
.. (355,181)
-- cycle) ;
setP ((228,149)
.. controls (242,111) and (261,75)
.. (284,44)
.. controls (237,55) and (195,79)
.. (160,111)
.. controls (179,125) and (202,138)
.. (228,149)
-- cycle) ;
setP ((183,325)
.. controls (184,283) and (196,228)
.. (217,174)
.. controls (187,161) and (160,147)
.. (139,132)
.. controls (93,183) and (65,250)
.. (62,325)
-- cycle) ;
setP ((62,355)
.. controls (65,430) and (93,497)
.. (139,548)
.. controls (160,533) and (187,519)
.. (217,506)
.. controls (197,452) and (185,398)
.. (183,355)
-- cycle) ;
setP ((227,532)
.. controls (201,543) and (178,556)
.. (160,569)
.. controls (195,601) and (237,625)
.. (284,637)
.. controls (262,607) and (242,570)
.. (227,532)
-- cycle) ;
setP ((385,649)
.. controls (395,649) and (405,648)
.. (416,646)
.. controls (443,609) and (468,567)
.. (487,521)
.. controls (454,509) and (418,501)
.. (385,499)
-- cycle) ;
setP ((385,468)
.. controls (419,470) and (458,480)
.. (496,496)
.. controls (514,449) and (525,402)
.. (527,355)
-- (385,355)
-- cycle) ;
setP ((527,325)
.. controls (525,280) and (514,232)
.. (496,184)
.. controls (458,200) and (419,210)
.. (385,212)
-- (385,325)
-- cycle) ;
setP ((385,181)
.. controls (417,179) and (452,172)
.. (486,160)
.. controls (468,115) and (444,71)
.. (416,34)
.. controls (405,32) and (395,31)
.. (385,31)
-- cycle) ;
setP ((513,532)
.. controls (498,570) and (478,607)
.. (456,637)
.. controls (503,625) and (545,601)
.. (580,569)
.. controls (562,556) and (539,543)
.. (513,532)
-- cycle) ;
setP ((557,355)
.. controls (555,398) and (543,452)
.. (523,506)
.. controls (553,519) and (580,533)
.. (601,548)
.. controls (647,497) and (675,430)
.. (678,355)
-- cycle) ;
setP ((678,325)
.. controls (675,250) and (647,183)
.. (601,132)
.. controls (580,147) and (553,161)
.. (523,174)
.. controls (544,228) and (556,283)
.. (557,325)
-- cycle) ;
setP ((512,149)
.. controls (538,138) and (561,125)
.. (580,111)
.. controls (545,79) and (503,55)
.. (456,44)
.. controls (479,75) and (498,111)
.. (512,149)
-- cycle) ;
endchar;

beginchar (100,760*FS#,553*FS#,0*FS#);
"d";
setP ((380,553)
-- (122,40)
-- (30,40)
-- (30,0)
-- (730,0)
-- (730,40)
-- (638,40)
-- cycle) ;
setP ((509,40)
-- (251,40)
-- (380,293)
-- cycle) ;
endchar;

beginchar (101,694*FS#,698*FS#,0*FS#);
"e";
setP ((347,698)
-- (260,472)
-- (30,472)
-- (206,330)
-- (141,103)
-- (347,237)
-- (553,103)
-- (478,330)
-- (664,472)
-- (435,472)
-- cycle) ;
endchar;

beginchar (102,708*FS#,506*FS#,0*FS#);
"f";
setP ((678,0)
-- (678,30)
-- (549,30)
-- (549,272)
-- (589,272)
-- (412,490)
-- (235,272)
-- (275,272)
-- (275,30)
-- (212,30)
-- (174,160)
-- (238,154)
.. controls (206,183) and (170,215)
.. (163,248)
.. controls (179,244) and (197,242)
.. (225,240)
.. controls (183,281) and (166,313)
.. (154,339)
.. controls (142,365) and (106,451)
.. (106,506)
-- (104,506)
.. controls (106,387) and (87,336)
.. (74,282)
.. controls (63,235) and (47,192)
.. (30,161)
.. controls (50,164) and (70,170)
.. (91,177)
.. controls (78,141) and (50,118)
.. (30,96)
.. controls (72,96) and (110,113)
.. (148,154)
.. controls (158,115) and (163,72)
.. (169,30)
-- (30,30)
-- (30,0)
-- cycle) ;
setP ((365,189)
-- (459,189)
-- (459,30)
-- (365,30)
-- cycle) ;
endchar;

beginchar (103,580*FS#,750*FS#,0*FS#);
"g";
setP ((300,481)
-- (300,616)
-- (418,683)
-- (280,750)
-- (280,481)
-- (50,276)
-- (170,276)
-- (170,0)
-- (410,0)
-- (410,276)
-- (530,276)
-- cycle) ;
endchar;

beginchar (104,682*FS#,650*FS#,0*FS#);
"h";
setP ((313,61)
.. controls (236,61) and (182,109)
.. (120,188)
-- (153,207)
.. controls (163,213) and (158,216)
.. (145,226)
.. controls (113,248) and (46,277)
.. (39,273)
.. controls (35,270) and (27,197)
.. (31,158)
.. controls (33,142) and (33,136)
.. (44,142)
-- (77,161)
.. controls (117,83) and (230,0)
.. (341,0)
.. controls (452,0) and (565,83)
.. (605,161)
-- (638,142)
.. controls (649,136) and (649,142)
.. (651,158)
.. controls (655,197) and (647,270)
.. (643,273)
.. controls (636,277) and (569,248)
.. (537,226)
.. controls (524,216) and (519,213)
.. (529,207)
-- (562,188)
.. controls (500,109) and (446,61)
.. (369,61)
-- (369,454)
.. controls (422,467) and (446,506)
.. (445,554)
.. controls (444,602) and (404,650)
.. (341,650)
.. controls (278,650) and (238,602)
.. (237,554)
.. controls (237,530) and (242,508)
.. (255,491)
.. controls (268,474) and (287,461)
.. (313,454)
-- cycle) ;
setP ((292,551)
.. controls (292,579) and (314,600)
.. (341,600)
.. controls (368,600) and (390,579)
.. (390,551)
.. controls (390,524) and (368,503)
.. (341,503)
.. controls (314,503) and (292,524)
.. (292,551)
-- cycle) ;
endchar;

beginchar (105,1005*FS#,921*FS#,121*FS#);
"i";
setP ((503,-121)
.. controls (597,-121) and (767,-18)
.. (853,90)
.. controls (945,206) and (1005,346)
.. (1005,508)
.. controls (1005,663) and (930,835)
.. (850,921)
.. controls (793,882) and (735,860)
.. (677,860)
.. controls (619,860) and (561,882)
.. (503,921)
.. controls (446,882) and (387,860)
.. (329,860)
.. controls (271,860) and (213,882)
.. (154,921)
.. controls (75,835) and (0,663)
.. (0,508)
.. controls (0,346) and (59,206)
.. (153,90)
.. controls (238,-18) and (408,-121)
.. (503,-121)
-- cycle) ;
setP ((941,700)
.. controls (952,671) and (975,605)
.. (975,508)
.. controls (975,377) and (936,246)
.. (827,104)
.. controls (767,25) and (601,-91)
.. (503,-91)
.. controls (405,-91) and (238,25)
.. (178,104)
.. controls (70,246) and (30,377)
.. (30,508)
.. controls (30,605) and (54,671)
.. (64,700)
-- cycle) ;
endchar;

beginchar (106,658*FS#,826*FS#,25*FS#);
"j";
setP ((191,58)
.. controls (176,45) and (167,35)
.. (167,26)
.. controls (167,16) and (178,12)
.. (189,12)
-- (274,12)
-- (276,38)
-- (295,38)
.. controls (300,13) and (311,-4)
.. (322,-7)
-- (329,-25)
-- (336,-7)
.. controls (347,-4) and (358,13)
.. (363,38)
-- (382,38)
-- (384,12)
-- (469,12)
.. controls (480,12) and (491,16)
.. (491,26)
.. controls (491,35) and (482,45)
.. (467,58)
-- (395,125)
-- (395,210)
-- (599,221)
-- (612,202)
-- (622,211)
-- (622,339)
-- (612,346)
-- (592,294)
-- (406,440)
.. controls (406,463) and (395,487)
.. (392,508)
-- (351,712)
.. controls (350,722) and (350,777)
.. (329,826)
.. controls (308,777) and (308,722)
.. (307,712)
-- (266,508)
.. controls (263,487) and (252,463)
.. (252,440)
-- (66,294)
-- (46,346)
-- (36,339)
-- (36,211)
-- (46,202)
-- (59,221)
-- (263,210)
-- (263,125)
-- cycle) ;
endchar;

beginchar (107,645*FS#,590*FS#,0*FS#);
"k";
setP ((180,400)
-- (25,210)
-- (91,210)
-- (246,400)
-- (91,590)
-- (25,590)
-- cycle) ;
setP ((615,429)
-- (615,474)
-- (317,474)
-- (222,590)
-- (156,590)
-- (288,429)
-- cycle) ;
setP ((288,371)
-- (156,210)
-- (222,210)
-- (317,326)
-- (615,326)
-- (615,371)
-- cycle) ;
endchar;

beginchar (108,800*FS#,800*FS#,0*FS#);
"l";
setP ((50,800)
.. controls (20,800) and (0,780)
.. (0,750)
-- (0,50)
.. controls (0,20) and (20,0)
.. (50,0)
-- (750,0)
.. controls (780,0) and (800,20)
.. (800,43)
-- (800,750)
.. controls (800,780) and (780,800)
.. (750,800)
-- cycle) ;
setP ((730,770)
.. controls (758,770) and (770,758)
.. (770,730)
-- (770,64)
.. controls (770,43) and (758,30)
.. (730,30)
-- (71,30)
.. controls (43,30) and (30,43)
.. (30,70)
-- (30,730)
.. controls (30,758) and (43,770)
.. (71,770)
-- cycle) ;
endchar;

beginchar (109,600*FS#,800*FS#,32*FS#);
"m";
setP ((55,45)
.. controls (43,39) and (30,34)
.. (30,20)
.. controls (30,-8) and (110,-32)
.. (300,-32)
.. controls (490,-32) and (570,-8)
.. (570,20)
.. controls (570,27) and (567,32)
.. (562,35)
.. controls (557,38) and (551,40)
.. (545,41)
-- (545,178)
.. controls (562,185) and (570,193)
.. (570,202)
.. controls (570,209) and (567,214)
.. (562,217)
.. controls (557,220) and (551,222)
.. (545,223)
-- (545,360)
.. controls (562,367) and (570,375)
.. (570,384)
.. controls (570,391) and (567,396)
.. (562,399)
.. controls (557,402) and (551,404)
.. (545,405)
-- (545,542)
.. controls (562,549) and (570,557)
.. (570,566)
.. controls (570,573) and (567,578)
.. (562,581)
.. controls (557,584) and (551,586)
.. (545,587)
-- (545,724)
.. controls (562,731) and (570,739)
.. (570,748)
.. controls (570,776) and (490,800)
.. (300,800)
.. controls (110,800) and (30,776)
.. (30,748)
.. controls (30,744) and (32,740)
.. (36,736)
.. controls (40,732) and (46,728)
.. (55,724)
-- (55,591)
.. controls (43,585) and (30,580)
.. (30,566)
.. controls (30,562) and (32,558)
.. (36,554)
.. controls (40,550) and (46,546)
.. (55,542)
-- (55,409)
.. controls (43,403) and (30,398)
.. (30,384)
.. controls (30,380) and (32,376)
.. (36,372)
.. controls (40,368) and (46,364)
.. (55,360)
-- (55,227)
.. controls (43,221) and (30,216)
.. (30,202)
.. controls (30,198) and (32,194)
.. (36,190)
.. controls (40,186) and (46,182)
.. (55,178)
-- cycle) ;
setP ((300,716)
.. controls (200,716) and (58,726)
.. (58,748)
.. controls (58,770) and (200,780)
.. (300,780)
.. controls (400,780) and (542,770)
.. (542,748)
.. controls (542,726) and (400,716)
.. (300,716)
-- cycle) ;
setP ((75,720)
.. controls (124,706) and (200,696)
.. (300,696)
.. controls (400,696) and (476,706)
.. (525,720)
-- (525,578)
.. controls (538,577) and (552,575)
.. (552,569)
.. controls (552,565) and (543,561)
.. (525,558)
.. controls (474,544) and (400,534)
.. (300,534)
.. controls (200,534) and (126,544)
.. (75,558)
.. controls (57,561) and (48,565)
.. (48,569)
.. controls (48,572) and (52,574)
.. (57,575)
.. controls (62,577) and (69,578)
.. (75,578)
-- cycle) ;
setP ((75,538)
.. controls (124,524) and (200,514)
.. (300,514)
.. controls (400,514) and (476,524)
.. (525,538)
-- (525,396)
.. controls (538,395) and (552,393)
.. (552,387)
.. controls (552,383) and (543,379)
.. (525,376)
.. controls (474,362) and (400,352)
.. (300,352)
.. controls (200,352) and (126,362)
.. (75,376)
.. controls (57,379) and (48,383)
.. (48,387)
.. controls (48,390) and (52,392)
.. (57,393)
.. controls (62,395) and (69,396)
.. (75,396)
-- cycle) ;
setP ((75,356)
.. controls (124,342) and (200,332)
.. (300,332)
.. controls (400,332) and (476,342)
.. (525,356)
-- (525,214)
.. controls (538,213) and (552,211)
.. (552,205)
.. controls (552,201) and (543,197)
.. (525,194)
.. controls (474,180) and (400,170)
.. (300,170)
.. controls (200,170) and (126,180)
.. (75,194)
.. controls (57,197) and (48,201)
.. (48,205)
.. controls (48,208) and (52,210)
.. (57,211)
.. controls (62,212) and (69,214)
.. (75,214)
-- cycle) ;
setP ((75,174)
.. controls (124,160) and (200,150)
.. (300,150)
.. controls (400,150) and (476,160)
.. (525,174)
-- (525,32)
.. controls (538,31) and (552,29)
.. (552,23)
.. controls (552,19) and (543,15)
.. (525,12)
.. controls (474,-2) and (400,-12)
.. (300,-12)
.. controls (200,-12) and (126,-2)
.. (75,12)
.. controls (57,15) and (48,19)
.. (48,23)
.. controls (48,26) and (52,28)
.. (57,29)
.. controls (62,30) and (69,32)
.. (75,32)
-- cycle) ;
endchar;

beginchar (110,764*FS#,800*FS#,0*FS#);
"n";
setP ((729,599)
.. controls (705,640) and (609,631)
.. (487,583)
.. controls (468,712) and (428,800)
.. (381,800)
.. controls (334,800) and (294,713)
.. (275,583)
.. controls (153,632) and (58,640)
.. (35,599)
.. controls (11,560) and (65,482)
.. (170,400)
.. controls (65,317) and (12,239)
.. (35,199)
.. controls (58,158) and (153,168)
.. (275,217)
.. controls (294,85) and (334,0)
.. (381,0)
.. controls (428,0) and (468,87)
.. (486,218)
.. controls (609,168) and (705,158)
.. (727,199)
.. controls (750,239) and (697,318)
.. (594,400)
.. controls (697,481) and (751,558)
.. (729,599)
-- cycle) ;
setP ((381,17)
.. controls (341,17) and (307,99)
.. (290,223)
.. controls (319,235) and (350,248)
.. (381,266)
.. controls (412,248) and (441,235)
.. (471,223)
.. controls (455,97) and (421,17)
.. (381,17)
-- cycle) ;
setP ((322,296)
.. controls (335,288) and (349,280)
.. (364,274)
.. controls (338,260) and (313,248)
.. (289,239)
.. controls (285,264) and (282,291)
.. (282,321)
.. controls (293,312) and (308,304)
.. (322,296)
-- cycle) ;
setP ((51,209)
.. controls (31,244) and (85,313)
.. (183,390)
.. controls (207,370) and (234,352)
.. (264,334)
.. controls (265,297) and (268,263)
.. (273,232)
.. controls (159,186) and (70,174)
.. (51,209)
-- cycle) ;
setP ((261,400)
.. controls (261,384) and (261,367)
.. (262,353)
.. controls (239,368) and (216,384)
.. (195,400)
.. controls (215,415) and (237,432)
.. (262,448)
.. controls (261,432) and (261,416)
.. (261,400)
-- cycle) ;
setP ((714,207)
.. controls (694,172) and (606,185)
.. (489,234)
.. controls (494,263) and (497,296)
.. (498,332)
.. controls (528,351) and (555,370)
.. (580,390)
.. controls (680,313) and (734,243)
.. (714,207)
-- cycle) ;
setP ((501,400)
.. controls (501,417) and (501,433)
.. (500,448)
.. controls (525,432) and (546,416)
.. (567,400)
.. controls (546,383) and (523,368)
.. (500,352)
.. controls (501,367) and (501,383)
.. (501,400)
-- cycle) ;
setP ((331,489)
.. controls (348,499) and (365,508)
.. (382,516)
.. controls (398,507) and (415,498)
.. (433,488)
.. controls (451,477) and (466,468)
.. (482,458)
.. controls (484,440) and (484,421)
.. (484,400)
.. controls (484,379) and (482,359)
.. (482,342)
.. controls (466,330) and (449,321)
.. (433,311)
.. controls (415,301) and (398,292)
.. (381,283)
.. controls (365,291) and (348,301)
.. (331,310)
.. controls (314,320) and (297,330)
.. (281,341)
.. controls (278,359) and (278,379)
.. (278,400)
.. controls (278,419) and (278,439)
.. (280,458)
.. controls (294,467) and (313,479)
.. (331,489)
-- cycle) ;
setP ((322,504)
.. controls (308,495) and (293,487)
.. (281,479)
.. controls (283,508) and (285,537)
.. (289,561)
.. controls (313,552) and (338,540)
.. (364,526)
.. controls (349,520) and (335,512)
.. (322,504)
-- cycle) ;
setP ((51,590)
.. controls (71,625) and (160,613)
.. (274,568)
.. controls (268,538) and (266,504)
.. (264,467)
.. controls (234,448) and (208,428)
.. (183,410)
.. controls (85,485) and (31,556)
.. (51,590)
-- cycle) ;
setP ((714,591)
.. controls (734,556) and (678,485)
.. (580,410)
.. controls (555,430) and (528,449)
.. (498,468)
.. controls (497,505) and (494,537)
.. (489,568)
.. controls (604,614) and (693,627)
.. (714,591)
-- cycle) ;
setP ((381,783)
.. controls (422,783) and (456,700)
.. (472,577)
.. controls (444,565) and (413,552)
.. (382,536)
.. controls (351,552) and (321,565)
.. (291,578)
.. controls (308,702) and (342,783)
.. (381,783)
-- cycle) ;
setP ((441,504)
.. controls (428,512) and (413,520)
.. (400,526)
.. controls (425,539) and (449,550)
.. (473,561)
.. controls (478,536) and (480,508)
.. (481,479)
.. controls (470,487) and (456,496)
.. (441,504)
-- cycle) ;
setP ((441,296)
.. controls (455,304) and (469,312)
.. (481,321)
.. controls (480,292) and (477,263)
.. (473,239)
.. controls (449,248) and (424,260)
.. (398,274)
.. controls (412,280) and (427,288)
.. (441,296)
-- cycle) ;
setP ((340,400)
.. controls (340,377) and (358,359)
.. (381,359)
.. controls (404,359) and (422,377)
.. (422,400)
.. controls (422,423) and (404,441)
.. (381,441)
.. controls (358,441) and (340,423)
.. (340,400)
-- cycle) ;
endchar;

beginchar (111,970*FS#,885*FS#,85*FS#);
"o";
setP ((0,400)
.. controls (0,129) and (213,-85)
.. (485,-85)
.. controls (757,-85) and (970,129)
.. (970,400)
.. controls (970,671) and (757,885)
.. (485,885)
.. controls (213,885) and (0,671)
.. (0,400)
-- cycle) ;
setP ((30,400)
.. controls (30,654) and (230,855)
.. (485,855)
.. controls (740,855) and (940,654)
.. (940,400)
.. controls (940,146) and (740,-55)
.. (485,-55)
.. controls (230,-55) and (30,146)
.. (30,400)
-- cycle) ;
endchar;

beginchar (112,1092*FS#,946*FS#,147*FS#);
"p";
setP ((17,436)
.. controls (-5,413) and (-5,385)
.. (17,364)
-- (512,-131)
.. controls (533,-152) and (561,-152)
.. (582,-131)
-- (1077,364)
.. controls (1099,385) and (1099,414)
.. (1077,435)
-- (582,930)
.. controls (561,951) and (533,952)
.. (512,930)
-- cycle) ;
setP ((514,892)
.. controls (533,912) and (559,911)
.. (579,892)
-- (1037,433)
.. controls (1058,414) and (1058,387)
.. (1037,367)
-- (579,-91)
.. controls (559,-111) and (533,-111)
.. (514,-91)
-- (55,367)
.. controls (35,387) and (35,413)
.. (55,434)
-- cycle) ;
endchar;

beginchar (113,899*FS#,700*FS#,0*FS#);
"q";
setP ((430,700)
-- (430,530)
-- (212,530)
-- (48,122)
.. controls (61,47) and (134,0)
.. (212,0)
.. controls (290,0) and (363,47)
.. (376,122)
-- (227,500)
-- (673,500)
-- (524,122)
.. controls (537,47) and (610,0)
.. (688,0)
.. controls (766,0) and (839,47)
.. (852,122)
-- (688,530)
-- (470,530)
-- (470,700)
-- cycle) ;
setP ((212,455)
-- (342,122)
-- (78,122)
-- cycle) ;
setP ((822,122)
-- (558,122)
-- (688,455)
-- cycle) ;
endchar;

beginchar (114,695*FS#,717*FS#,0*FS#);
"r";
setP ((30,400)
.. controls (30,223) and (170,83)
.. (347,83)
.. controls (524,83) and (665,223)
.. (665,400)
.. controls (665,577) and (524,717)
.. (347,717)
.. controls (170,717) and (30,577)
.. (30,400)
-- cycle) ;
setP ((348,687)
-- (414,492)
-- (624,492)
-- (455,366)
-- (507,162)
-- (348,289)
-- (188,162)
-- (240,366)
-- (71,492)
-- (281,492)
-- cycle) ;
endchar;

beginchar (115,762*FS#,915*FS#,116*FS#);
"s";
setP ((527,904)
.. controls (523,921) and (502,919)
.. (503,898)
.. controls (507,868) and (511,823)
.. (475,799)
.. controls (449,781) and (394,795)
.. (364,811)
.. controls (346,819) and (340,803)
.. (355,793)
.. controls (379,781) and (418,767)
.. (453,771)
.. controls (431,748) and (418,720)
.. (418,687)
.. controls (418,615) and (464,561)
.. (527,546)
.. controls (537,543) and (527,513)
.. (523,503)
-- (498,451)
.. controls (489,430) and (454,426)
.. (431,426)
-- (164,426)
.. controls (80,426) and (30,365)
.. (30,325)
.. controls (30,231) and (138,192)
.. (143,139)
-- (146,104)
.. controls (124,104) and (122,93)
.. (122,82)
.. controls (122,67) and (151,61)
.. (180,48)
-- (237,-60)
.. controls (245,-72) and (254,-84)
.. (263,-80)
.. controls (271,-74) and (269,-59)
.. (265,-47)
-- (232,28)
-- (369,-32)
-- (349,-84)
.. controls (343,-97) and (343,-113)
.. (353,-116)
.. controls (359,-119) and (371,-108)
.. (377,-94)
-- (407,-35)
.. controls (418,-12) and (437,14)
.. (444,35)
.. controls (457,67) and (472,105)
.. (479,132)
.. controls (484,158) and (499,165)
.. (521,165)
.. controls (554,165) and (560,153)
.. (560,147)
.. controls (560,136) and (546,117)
.. (534,106)
-- (484,43)
.. controls (475,31) and (472,13)
.. (476,7)
.. controls (484,2) and (503,13)
.. (514,23)
-- (572,96)
.. controls (606,137) and (637,162)
.. (637,189)
.. controls (637,210) and (567,221)
.. (567,252)
-- (567,304)
.. controls (567,331) and (589,378)
.. (602,423)
.. controls (610,451) and (654,451)
.. (698,459)
.. controls (718,461) and (732,466)
.. (732,485)
.. controls (732,501) and (718,509)
.. (705,513)
-- (559,572)
.. controls (547,665) and (612,709)
.. (689,711)
.. controls (709,712) and (709,726)
.. (689,729)
.. controls (666,730) and (645,726)
.. (627,722)
.. controls (642,746) and (641,769)
.. (636,789)
.. controls (633,799) and (618,798)
.. (618,782)
.. controls (618,759) and (620,730)
.. (592,711)
.. controls (567,695) and (531,709)
.. (511,717)
.. controls (497,722) and (493,709)
.. (503,703)
.. controls (519,695) and (542,686)
.. (563,687)
.. controls (540,661) and (524,624)
.. (529,578)
.. controls (475,596) and (451,642)
.. (451,691)
.. controls (451,758) and (516,807)
.. (596,820)
.. controls (605,821) and (605,834)
.. (596,836)
.. controls (573,838) and (542,833)
.. (516,820)
.. controls (525,836) and (529,851)
.. (531,865)
.. controls (532,879) and (530,893)
.. (527,904)
-- cycle) ;
setP ((386,173)
-- (386,144)
.. controls (386,118) and (406,93)
.. (406,65)
.. controls (406,50) and (393,27)
.. (379,-9)
-- (220,75)
.. controls (200,84) and (207,96)
.. (215,105)
.. controls (232,121) and (250,147)
.. (264,173)
-- cycle) ;
endchar;

beginchar (116,695*FS#,717*FS#,0*FS#);
"t";
setP ((30,400)
.. controls (30,223) and (170,83)
.. (347,83)
.. controls (524,83) and (665,223)
.. (665,400)
.. controls (665,577) and (524,717)
.. (347,717)
.. controls (170,717) and (30,577)
.. (30,400)
-- cycle) ;
setP ((60,400)
.. controls (60,561) and (187,687)
.. (348,687)
.. controls (508,687) and (635,561)
.. (635,400)
.. controls (635,239) and (508,113)
.. (348,113)
.. controls (187,113) and (60,239)
.. (60,400)
-- cycle) ;
setP ((531,400)
.. controls (531,508) and (456,584)
.. (348,584)
.. controls (240,584) and (164,508)
.. (164,400)
.. controls (164,292) and (240,216)
.. (348,216)
.. controls (456,216) and (531,292)
.. (531,400)
-- cycle) ;
endchar;

beginchar (117,1063*FS#,921*FS#,122*FS#);
"u";
setP ((30,748)
.. controls (58,736) and (97,664)
.. (97,608)
.. controls (97,545) and (0,460)
.. (0,299)
.. controls (0,83) and (151,-88)
.. (265,-88)
.. controls (315,-88) and (344,-79)
.. (367,-69)
.. controls (391,-60) and (409,-50)
.. (425,-50)
.. controls (456,-50) and (499,-84)
.. (531,-122)
.. controls (563,-84) and (607,-50)
.. (638,-50)
.. controls (654,-50) and (672,-60)
.. (696,-69)
.. controls (719,-79) and (747,-88)
.. (798,-88)
.. controls (912,-88) and (1063,83)
.. (1063,299)
.. controls (1063,460) and (966,545)
.. (966,608)
.. controls (967,664) and (1006,736)
.. (1034,748)
-- (845,921)
.. controls (790,862) and (737,824)
.. (689,824)
.. controls (637,824) and (557,862)
.. (531,921)
.. controls (505,862) and (427,824)
.. (375,824)
.. controls (327,824) and (274,862)
.. (218,921)
-- cycle) ;
setP ((992,748)
.. controls (958,715) and (936,659)
.. (936,608)
.. controls (936,525) and (1033,458)
.. (1033,299)
.. controls (1033,124) and (911,-58)
.. (795,-58)
.. controls (764,-58) and (733,-55)
.. (710,-46)
.. controls (687,-37) and (670,-20)
.. (632,-20)
.. controls (595,-17) and (562,-53)
.. (531,-83)
.. controls (500,-53) and (467,-17)
.. (430,-20)
.. controls (392,-20) and (375,-37)
.. (352,-46)
.. controls (329,-55) and (298,-58)
.. (267,-58)
.. controls (151,-58) and (29,124)
.. (29,299)
.. controls (29,458) and (126,525)
.. (126,608)
.. controls (126,659) and (104,715)
.. (70,748)
-- (218,885)
.. controls (249,844) and (323,794)
.. (375,794)
.. controls (433,794) and (499,828)
.. (531,874)
.. controls (563,828) and (629,794)
.. (687,794)
.. controls (739,794) and (813,844)
.. (844,885)
-- cycle) ;
endchar;

beginchar (118,740*FS#,587*FS#,0*FS#);
"v";
setP ((370,587)
-- (30,466)
-- (231,394)
-- (184,228)
-- (557,228)
-- (510,395)
-- (566,415)
-- (638,157)
-- (686,202)
-- (581,421)
-- (710,466)
-- cycle) ;
setP ((217,248)
-- (255,386)
-- (370,345)
-- (486,387)
-- (524,248)
-- cycle) ;
endchar;

beginchar (119,808*FS#,724*FS#,2*FS#);
"w";
setP ((97,469)
-- (194,372)
-- (269,447)
-- (516,200)
.. controls (494,188) and (472,179)
.. (445,175)
.. controls (387,166) and (304,186)
.. (255,262)
-- (221,262)
-- (170,213)
.. controls (150,240) and (136,245)
.. (125,233)
.. controls (114,222) and (119,208)
.. (145,189)
.. controls (109,168) and (68,135)
.. (43,110)
.. controls (26,93) and (25,62)
.. (42,45)
.. controls (59,28) and (90,30)
.. (107,47)
.. controls (131,71) and (165,113)
.. (185,149)
.. controls (205,122) and (218,117)
.. (230,129)
.. controls (241,140) and (236,153)
.. (209,173)
-- (229,193)
.. controls (257,134) and (364,76)
.. (459,78)
.. controls (506,78) and (558,93)
.. (598,118)
-- (707,9)
.. controls (725,-9) and (747,-2)
.. (763,14)
.. controls (780,30) and (785,52)
.. (768,70)
-- (661,177)
.. controls (708,221) and (732,308)
.. (731,399)
.. controls (730,546) and (601,691)
.. (417,724)
-- (415,722)
.. controls (529,630) and (623,545)
.. (630,431)
.. controls (633,365) and (616,285)
.. (583,254)
-- (329,508)
-- (421,599)
-- (257,627)
-- cycle) ;
endchar;

beginchar (120,660*FS#,600*FS#,0*FS#);
"x";
setP ((30,300)
.. controls (30,132) and (162,0)
.. (330,0)
.. controls (498,0) and (630,132)
.. (630,300)
.. controls (630,468) and (498,600)
.. (330,600)
.. controls (162,600) and (30,468)
.. (30,300)
-- cycle) ;
setP ((407,377)
-- (545,377)
-- (545,223)
-- (407,223)
-- (407,85)
-- (253,85)
-- (253,223)
-- (115,223)
-- (115,377)
-- (253,377)
-- (253,515)
-- (407,515)
-- cycle) ;
endchar;

beginchar (121,700*FS#,921*FS#,122*FS#);
"y";
setP ((700,856)
-- (568,921)
.. controls (529,899) and (496,884)
.. (459,884)
.. controls (423,884) and (371,899)
.. (350,921)
.. controls (329,899) and (277,884)
.. (241,884)
.. controls (205,884) and (171,899)
.. (132,921)
-- (0,856)
-- (0,606)
.. controls (16,555) and (34,503)
.. (34,451)
.. controls (34,425) and (30,399)
.. (23,373)
.. controls (17,347) and (8,322)
.. (0,296)
.. controls (0,196) and (41,101)
.. (106,21)
.. controls (166,-52) and (285,-122)
.. (350,-122)
.. controls (416,-122) and (534,-52)
.. (594,21)
.. controls (658,101) and (700,196)
.. (700,296)
.. controls (684,347) and (666,399)
.. (666,451)
.. controls (666,477) and (671,503)
.. (677,529)
.. controls (684,555) and (692,581)
.. (700,606)
-- cycle) ;
setP ((30,841)
-- (132,891)
.. controls (167,871) and (203,856)
.. (241,854)
.. controls (274,856) and (322,871)
.. (350,891)
.. controls (378,871) and (426,856)
.. (459,854)
.. controls (497,856) and (533,871)
.. (568,891)
-- (670,841)
-- (670,599)
.. controls (649,551) and (636,497)
.. (636,448)
.. controls (636,424) and (639,398)
.. (645,372)
.. controls (651,347) and (660,321)
.. (670,297)
.. controls (670,208) and (633,118)
.. (573,43)
.. controls (518,-26) and (406,-92)
.. (350,-92)
.. controls (294,-92) and (182,-26)
.. (127,43)
.. controls (67,118) and (30,208)
.. (30,297)
.. controls (51,345) and (64,399)
.. (64,448)
.. controls (64,473) and (61,498)
.. (55,524)
.. controls (49,550) and (41,575)
.. (30,599)
-- cycle) ;
endchar;

beginchar (122,340*FS#,645*FS#,10*FS#);
"z";
setP ((56,192)
.. controls (49,175) and (15,93)
.. (15,45)
.. controls (15,7) and (40,-10)
.. (76,-10)
.. controls (177,-10) and (294,114)
.. (294,143)
.. controls (294,152) and (287,158)
.. (282,158)
.. controls (268,158) and (213,73)
.. (183,73)
.. controls (175,73) and (171,80)
.. (171,87)
.. controls (171,103) and (182,128)
.. (188,143)
-- (260,338)
.. controls (296,435) and (250,461)
.. (207,461)
.. controls (149,461) and (97,432)
.. (57,394)
.. controls (44,381) and (0,339)
.. (0,321)
.. controls (0,315) and (6,308)
.. (13,308)
.. controls (31,308) and (79,395)
.. (116,395)
.. controls (124,395) and (133,386)
.. (126,368)
-- cycle) ;
setP ((248,497)
.. controls (293,497) and (331,531)
.. (331,577)
.. controls (331,618) and (302,645)
.. (262,645)
.. controls (218,645) and (180,609)
.. (180,565)
.. controls (180,524) and (207,497)
.. (248,497)
-- cycle) ;
endchar;

beginchar (123,1811*FS#,153*FS#,0*FS#);
"braceleft";
setP ((1811,0)
-- (1811,153)
-- (0,153)
-- (0,0)
-- cycle) ;
setP ((14,14)
-- (14,75)
-- (131,75)
-- (131,14)
-- cycle) ;
setP ((250,139)
-- (250,78)
-- (133,78)
-- (133,139)
-- cycle) ;
setP ((252,14)
-- (252,75)
-- (369,75)
-- (369,14)
-- cycle) ;
setP ((488,139)
-- (488,78)
-- (371,78)
-- (371,139)
-- cycle) ;
setP ((490,14)
-- (490,75)
-- (607,75)
-- (607,14)
-- cycle) ;
setP ((1202,139)
-- (1202,78)
-- (609,78)
-- (609,139)
-- cycle) ;
setP ((1204,75)
-- (1797,75)
-- (1797,14)
-- (1204,14)
-- cycle) ;
endchar;

beginchar (124,900*FS#,717*FS#,0*FS#);
"bar";
setP ((763,717)
-- (356,717)
-- (223,585)
-- (532,585)
-- (130,183)
-- (229,84)
-- (631,486)
-- (631,177)
-- (763,310)
-- cycle) ;
endchar;

beginchar (125,900*FS#,717*FS#,0*FS#);
"braceright";
setP ((130,310)
-- (262,177)
-- (262,486)
-- (664,84)
-- (763,183)
-- (361,585)
-- (670,585)
-- (537,717)
-- (130,717)
-- cycle) ;
endchar;

beginchar (126,575*FS#,681*FS#,5*FS#);
"asciitilde";
setP ((322,630)
.. controls (322,602) and (344,580)
.. (373,580)
.. controls (401,580) and (423,602)
.. (423,630)
.. controls (423,659) and (401,681)
.. (373,681)
.. controls (344,681) and (322,659)
.. (322,630)
-- cycle) ;
setP ((534,392)
-- (514,390)
-- (518,438)
-- (457,556)
-- (416,568)
.. controls (403,573) and (378,569)
.. (368,561)
-- (341,541)
-- (311,428)
-- (253,409)
-- (224,472)
-- (191,485)
.. controls (176,491) and (158,491)
.. (147,483)
-- (119,460)
-- (88,368)
-- (30,314)
-- (42,292)
-- (107,340)
-- (125,381)
-- (138,339)
-- (83,211)
-- (100,204)
-- (54,35)
-- (76,24)
-- (140,198)
-- (167,193)
-- (246,27)
-- (273,38)
-- (213,196)
-- (251,208)
-- (217,288)
-- (282,292)
-- (272,354)
-- (239,352)
-- (258,381)
-- (320,390)
-- (347,430)
-- (366,330)
-- (320,213)
-- (306,9)
-- (352,0)
-- (364,169)
-- (399,244)
-- (414,158)
-- (500,-5)
-- (542,17)
-- (465,161)
-- (465,309)
-- (545,317)
-- cycle) ;
setP ((105,554)
.. controls (105,526) and (127,504)
.. (155,504)
.. controls (184,504) and (206,526)
.. (206,554)
.. controls (206,583) and (184,605)
.. (155,605)
.. controls (127,605) and (105,583)
.. (105,554)
-- cycle) ;
setP ((219,351)
-- (205,351)
-- (211,407)
-- (231,378)
-- cycle) ;
setP ((487,434)
-- (479,386)
-- (459,384)
-- (452,478)
-- cycle) ;
endchar;

beginchar (161,1000*FS#,894*FS#,94*FS#);
"degree";
setP ((75,796)
.. controls (29,796) and (0,775)
.. (0,652)
.. controls (0,439) and (211,129)
.. (430,-66)
.. controls (471,-103) and (529,-103)
.. (570,-66)
.. controls (789,129) and (1000,439)
.. (1000,652)
.. controls (1000,775) and (971,796)
.. (925,796)
-- (629,796)
-- (629,859)
.. controls (629,881) and (615,894)
.. (593,894)
-- (407,894)
.. controls (384,894) and (371,881)
.. (371,859)
-- (371,796)
-- cycle) ;
endchar;

beginchar (162,560*FS#,683*FS#,0*FS#);
"cent";
setP ((563,400)
-- (280,683)
-- (-3,400)
-- (280,117)
-- cycle) ;
endchar;

beginchar (163,560*FS#,650*FS#,0*FS#);
"sterling";
setP ((530,150)
-- (280,650)
-- (30,150)
-- cycle) ;
endchar;

beginchar (164,2600*FS#,447*FS#,0*FS#);
"section";
setP ((2556,126)
-- (1500,126)
-- (1500,169)
-- (1488,169)
-- (1488,156)
-- (1469,156)
.. controls (1464,156) and (1458,161)
.. (1451,168)
.. controls (1446,173) and (1439,181)
.. (1430,181)
-- (1403,181)
-- (1403,161)
-- (1410,161)
-- (1410,126)
-- (1383,126)
-- (1383,260)
-- (1371,260)
-- (1371,344)
-- (1359,344)
-- (1359,260)
-- (1262,260)
-- (1262,226)
-- (1220,226)
-- (1220,240)
-- (1232,240)
-- (1220,253)
-- (1220,274)
.. controls (1238,289) and (1259,296)
.. (1259,308)
-- (1259,321)
-- (1307,321)
-- (1307,343)
-- (1220,343)
-- (1220,369)
-- (1241,369)
-- (1241,414)
-- (1238,414)
.. controls (1237,406) and (1227,393)
.. (1220,394)
-- (1220,447)
-- (1208,447)
-- (1208,395)
-- (1180,395)
-- (1208,369)
-- (1208,343)
.. controls (1207,343) and (1200,340)
.. (1200,333)
.. controls (1200,324) and (1207,321)
.. (1214,321)
-- (1214,309)
.. controls (1205,309) and (1197,303)
.. (1195,296)
-- (1174,296)
-- (1157,321)
-- (1147,321)
.. controls (1140,315) and (1141,297)
.. (1151,297)
-- (1163,297)
-- (1170,287)
-- (1170,274)
-- (1200,249)
-- (1200,226)
-- (1179,226)
-- (1167,240)
-- (1146,201)
-- (1131,201)
-- (1131,243)
-- (1116,259)
-- (1112,254)
-- (1123,242)
-- (1112,214)
-- (1086,214)
-- (1086,126)
-- (30,126)
-- (30,113)
-- (62,113)
.. controls (71,68) and (153,59)
.. (169,0)
-- (2484,0)
-- (2549,39)
-- (2518,39)
-- (2518,54)
-- (2502,73)
-- (2502,92)
-- (2570,92)
-- cycle) ;
setP ((1245,321)
-- (1245,309)
.. controls (1233,308) and (1225,310)
.. (1224,321)
-- cycle) ;
setP ((1423,161)
.. controls (1449,161) and (1474,140)
.. (1480,126)
-- (1423,126)
-- cycle) ;
endchar;

beginchar (165,1676*FS#,372*FS#,0*FS#);
"bullet";
setP ((1284,160)
-- (1046,160)
-- (1046,275)
-- (1036,275)
-- (1036,160)
-- (868,160)
-- (868,241)
-- (858,241)
-- (858,160)
-- (274,160)
-- (192,262)
-- (192,299)
-- (182,299)
-- (182,160)
-- (30,160)
.. controls (28,117) and (91,95)
.. (96,73)
-- (114,0)
-- (1444,0)
.. controls (1550,0) and (1630,107)
.. (1646,160)
-- (1568,160)
-- (1568,197)
-- (1531,197)
-- (1531,234)
-- (1484,234)
-- (1428,372)
-- (1348,372)
-- (1368,234)
-- (1330,234)
-- (1330,264)
.. controls (1306,264) and (1284,246)
.. (1284,215)
-- cycle) ;
setP ((192,240)
-- (194,240)
-- (258,160)
-- (192,160)
-- cycle) ;
endchar;

beginchar (166,1800*FS#,499*FS#,0*FS#);
"paragraph";
setP ((41,116)
-- (30,116)
.. controls (30,96) and (28,14)
.. (60,0)
-- (1744,0)
-- (1770,48)
-- (1770,164)
-- (1758,164)
-- (1758,107)
-- (1743,87)
-- (1699,80)
-- (1699,123)
-- (1710,123)
-- (1710,134)
-- (1672,134)
-- (1672,123)
-- (1687,123)
-- (1687,77)
-- (1508,58)
-- (1508,83)
-- (1465,83)
-- (1465,145)
-- (1455,145)
-- (1455,83)
-- (1437,83)
-- (1437,145)
-- (1427,145)
-- (1427,83)
-- (1413,83)
-- (1413,58)
-- (1339,58)
-- (1339,86)
-- (1362,98)
-- (1362,114)
-- (1319,89)
-- (1319,58)
-- (1138,58)
-- (1138,72)
-- (1189,72)
-- (1189,84)
-- (1138,84)
-- (1112,94)
-- (1096,94)
-- (1108,79)
-- (1108,58)
-- (1064,58)
-- (1064,88)
-- (1025,88)
-- (1025,118)
-- (1034,123)
-- (1034,130)
-- (1016,134)
-- (1123,201)
-- (1118,207)
-- (1018,162)
-- (1018,188)
-- (1024,188)
-- (1024,200)
-- (1006,200)
-- (1006,172)
-- (991,172)
-- (991,194)
-- (979,194)
-- (979,172)
-- (969,172)
-- (956,213)
-- (966,213)
-- (966,234)
-- (944,234)
-- (944,205)
-- (906,205)
-- (906,251)
-- (944,251)
-- (944,279)
-- (938,302)
-- (938,318)
-- (948,318)
-- (948,326)
-- (927,326)
-- (927,312)
-- (895,312)
-- (895,339)
-- (908,339)
-- (908,370)
-- (870,370)
-- (870,339)
-- (883,339)
-- (883,312)
-- (871,312)
-- (851,332)
-- (851,394)
.. controls (858,397) and (863,401)
.. (864,408)
-- (898,408)
-- (898,419)
-- (864,419)
.. controls (863,426) and (858,432)
.. (851,433)
-- (851,499)
-- (840,499)
-- (840,433)
.. controls (832,432) and (827,426)
.. (826,419)
-- (792,419)
-- (792,408)
-- (826,408)
.. controls (827,401) and (832,397)
.. (840,394)
-- (840,293)
.. controls (840,286) and (845,277)
.. (853,270)
.. controls (859,263) and (868,256)
.. (877,251)
-- (877,205)
-- (844,205)
-- (844,214)
-- (851,218)
-- (839,230)
-- (826,218)
-- (832,214)
-- (832,205)
-- (823,205)
-- (823,172)
-- (782,172)
-- (763,123)
-- (683,123)
-- (663,210)
-- (692,227)
-- (692,309)
-- (703,313)
-- (703,328)
-- (697,332)
-- (697,424)
-- (685,424)
-- (685,333)
-- (672,333)
.. controls (671,341) and (667,345)
.. (659,345)
.. controls (655,345) and (651,342)
.. (651,336)
.. controls (651,330) and (653,325)
.. (659,325)
-- (680,325)
-- (680,263)
-- (651,263)
-- (651,277)
.. controls (660,278) and (668,285)
.. (668,291)
.. controls (668,298) and (663,305)
.. (645,305)
.. controls (627,305) and (624,298)
.. (624,291)
.. controls (624,285) and (629,278)
.. (639,277)
-- (639,263)
-- (631,238)
-- (613,238)
-- (611,217)
-- (626,217)
-- (623,170)
-- (595,170)
-- (589,143)
-- (551,143)
-- (536,175)
-- (536,187)
-- (545,187)
-- (545,194)
.. controls (524,196) and (520,211)
.. (520,225)
-- (508,225)
-- (508,215)
.. controls (508,205) and (514,194)
.. (522,187)
-- (522,175)
-- (505,145)
-- (490,145)
-- (473,183)
-- (457,188)
-- (457,243)
-- (446,243)
-- (446,82)
-- (427,79)
.. controls (425,87) and (413,94)
.. (403,94)
.. controls (390,94) and (377,90)
.. (375,82)
-- (331,82)
-- (331,75)
-- (375,68)
-- (375,58)
-- (281,58)
-- (281,70)
-- (292,83)
-- (292,95)
-- (244,95)
-- (244,83)
-- (255,70)
-- (255,58)
-- (41,83)
-- cycle) ;
setP ((457,175)
-- (465,175)
-- (480,142)
-- (465,130)
-- (457,136)
-- cycle) ;
setP ((680,255)
-- (680,241)
-- (659,227)
-- (652,255)
-- cycle) ;
setP ((902,277)
-- (902,293)
-- (913,301)
-- (927,301)
-- (927,269)
-- (913,269)
-- cycle) ;
endchar;

beginchar (167,963*FS#,595*FS#,0*FS#);
"germandbls";
setP ((933,595)
-- (930,595)
.. controls (923,566) and (756,421)
.. (749,421)
.. controls (726,421) and (515,576)
.. (344,576)
.. controls (188,576) and (30,436)
.. (30,400)
.. controls (30,364) and (188,224)
.. (344,224)
.. controls (515,224) and (726,379)
.. (749,379)
.. controls (756,379) and (923,234)
.. (930,205)
-- (933,205)
-- cycle) ;
endchar;

beginchar (168,695*FS#,717*FS#,0*FS#);
"registered";
setP ((30,400)
.. controls (30,223) and (170,83)
.. (347,83)
.. controls (524,83) and (665,223)
.. (665,400)
.. controls (665,577) and (524,717)
.. (347,717)
.. controls (170,717) and (30,577)
.. (30,400)
-- cycle) ;
setP ((60,400)
.. controls (60,561) and (187,687)
.. (347,687)
.. controls (508,687) and (635,561)
.. (635,400)
.. controls (635,239) and (508,113)
.. (347,113)
.. controls (187,113) and (60,239)
.. (60,400)
-- cycle) ;
setP reverse ((409,491)
-- (619,491)
-- (450,364)
-- (516,164)
-- (347,288)
-- (179,164)
-- (246,364)
-- (75,491)
-- (284,491)
-- (347,687)
-- cycle) ;
setP ((347,591)
-- (382,465)
-- (534,465)
-- (414,380)
-- (458,243)
-- (347,330)
-- (237,243)
-- (282,380)
-- (159,465)
-- (312,465)
-- cycle) ;
endchar;

beginchar (169,436*FS#,750*FS#,0*FS#);
"copyright";
setP ((218,750)
-- (50,248)
-- (203,248)
-- (203,30)
-- (50,30)
-- (50,0)
-- (386,0)
-- (386,30)
-- (233,30)
-- (233,248)
-- (386,248)
-- cycle) ;
endchar;

beginchar (170,560*FS#,600*FS#,0*FS#);
"trademark";
setP ((480,200)
-- (480,600)
-- (80,600)
-- (80,200)
-- cycle) ;
endchar;

beginchar (171,694*FS#,697*FS#,0*FS#);
"acute";
setP ((347,697)
-- (260,471)
-- (30,471)
-- (206,329)
-- (141,102)
-- (347,236)
-- (553,102)
-- (478,329)
-- (664,471)
-- (435,471)
-- cycle) ;
setP ((417,457)
-- (617,457)
-- (617,455)
-- (347,375)
-- cycle) ;
setP ((458,342)
-- (526,142)
-- (524,141)
-- (347,375)
-- cycle) ;
setP ((347,255)
-- (167,135)
-- (165,140)
-- (347,374)
-- cycle) ;
setP ((225,335)
-- (76,452)
-- (78,454)
-- (347,375)
-- cycle) ;
setP ((273,462)
-- (345,652)
-- (347,652)
-- (347,375)
-- cycle) ;
endchar;

beginchar (172,960*FS#,871*FS#,71*FS#);
"dieresis";
setP ((150,871)
.. controls (37,871) and (-7,835)
.. (1,757)
-- (88,62)
.. controls (99,-33) and (141,-71)
.. (222,-71)
-- (738,-71)
.. controls (819,-71) and (859,-33)
.. (872,62)
-- (958,757)
.. controls (968,835) and (923,871)
.. (810,871)
-- cycle) ;
setP ((799,841)
.. controls (905,841) and (934,807)
.. (925,734)
-- (845,84)
.. controls (834,-5) and (807,-41)
.. (731,-41)
-- (230,-41)
.. controls (154,-41) and (126,-5)
.. (115,84)
-- (34,734)
.. controls (25,807) and (56,841)
.. (162,841)
-- cycle) ;
endchar;

beginchar (173,596*FS#,750*FS#,0*FS#);
"notequal";
setP ((566,0)
-- (566,80)
-- (480,80)
-- (406,507)
-- (190,507)
-- (116,80)
-- (30,80)
-- (30,0)
-- cycle) ;
setP ((459,557)
-- (534,690)
-- (534,750)
-- (479,750)
-- (436,675)
-- (379,675)
-- (347,750)
-- (249,750)
-- (217,675)
-- (155,675)
-- (116,742)
-- (62,742)
-- (62,688)
-- (137,557)
-- cycle) ;
endchar;

beginchar (174,500*FS#,500*FS#,0*FS#);
"AE";
setP ((235,265)
-- (0,265)
-- (0,235)
-- (235,235)
-- (235,0)
-- (265,0)
-- (265,235)
-- (500,235)
-- (500,265)
-- (265,265)
-- (265,500)
-- (235,500)
-- cycle) ;
endchar;

beginchar (175,854*FS#,880*FS#,80*FS#);
"Oslash";
setP ((0,122)
.. controls (0,-80) and (189,-80)
.. (426,-80)
.. controls (665,-80) and (854,-80)
.. (854,122)
-- (854,272)
.. controls (854,441) and (818,594)
.. (722,679)
.. controls (584,801) and (491,851)
.. (426,880)
.. controls (362,851) and (270,801)
.. (131,679)
.. controls (35,594) and (0,441)
.. (0,272)
-- cycle) ;
setP ((30,280)
.. controls (30,430) and (63,581)
.. (152,661)
.. controls (281,776) and (367,822)
.. (426,850)
.. controls (487,822) and (573,776)
.. (701,661)
.. controls (791,581) and (824,430)
.. (824,280)
-- (824,131)
.. controls (824,-50) and (668,-50)
.. (426,-50)
.. controls (186,-50) and (30,-50)
.. (30,131)
-- cycle) ;
endchar;

beginchar (176,560*FS#,650*FS#,0*FS#);
"infinity";
setP ((424,150)
-- (569,400)
-- (424,650)
-- (136,650)
-- (-9,400)
-- (136,150)
-- cycle) ;
endchar;

beginchar (177,600*FS#,620*FS#,0*FS#);
"plusminus";
setP ((92,180)
.. controls (215,241) and (386,241)
.. (509,180)
-- (520,192)
.. controls (463,314) and (459,486)
.. (520,608)
-- (509,620)
.. controls (386,559) and (215,559)
.. (92,620)
-- (80,608)
.. controls (137,486) and (141,314)
.. (80,192)
-- cycle) ;
setP ((300,526)
.. controls (370,526) and (430,550)
.. (485,587)
-- (487,585)
.. controls (450,529) and (426,471)
.. (426,400)
.. controls (426,328) and (450,271)
.. (487,215)
-- (485,214)
.. controls (430,251) and (367,274)
.. (300,274)
.. controls (227,274) and (171,251)
.. (116,214)
-- (114,215)
.. controls (151,271) and (174,326)
.. (174,400)
.. controls (174,466) and (151,529)
.. (114,585)
-- (116,587)
.. controls (171,550) and (229,526)
.. (300,526)
-- cycle) ;
endchar;

beginchar (178,590*FS#,750*FS#,0*FS#);
"lessequal";
setP ((560,0)
-- (560,30)
-- (359,30)
-- (284,502)
-- (344,502)
.. controls (344,370) and (434,287)
.. (538,287)
-- (538,289)
.. controls (474,317) and (420,399)
.. (420,519)
.. controls (420,639) and (474,720)
.. (538,748)
-- (538,750)
.. controls (434,750) and (344,667)
.. (344,532)
-- (279,532)
-- (268,600)
-- (165,600)
-- (165,30)
-- (30,30)
-- (30,0)
-- cycle) ;
setP ((459,519)
.. controls (459,493) and (479,473)
.. (503,473)
.. controls (528,473) and (548,493)
.. (548,519)
.. controls (548,544) and (528,563)
.. (503,563)
.. controls (479,563) and (459,544)
.. (459,519)
-- cycle) ;
endchar;

beginchar (179,632*FS#,677*FS#,0*FS#);
"greaterequal";
setP ((316,412)
-- (52,677)
-- (30,656)
-- (295,391)
-- (149,245)
-- (101,294)
-- (70,262)
.. controls (43,238) and (37,154)
.. (58,133)
.. controls (78,113) and (162,120)
.. (187,145)
-- (219,176)
-- (170,224)
-- (316,370)
-- (462,224)
-- (414,176)
-- (445,145)
.. controls (470,120) and (554,113)
.. (574,133)
.. controls (595,154) and (588,237)
.. (562,262)
-- (531,294)
-- (483,245)
-- (337,391)
-- (602,656)
-- (581,677)
-- cycle) ;
endchar;

beginchar (180,700*FS#,800*FS#,0*FS#);
"yen";
setP ((0,800)
-- (0,300)
.. controls (0,110) and (180,0)
.. (350,0)
.. controls (520,0) and (700,110)
.. (700,300)
-- (700,800)
-- cycle) ;
setP ((670,770)
-- (670,308)
.. controls (670,138) and (505,30)
.. (350,30)
.. controls (195,30) and (30,138)
.. (30,308)
-- (30,770)
-- cycle) ;
endchar;

beginchar (181,626*FS#,579*FS#,0*FS#);
"mu";
setP ((585,370)
-- (35,370)
-- (135,130)
-- (485,130)
-- cycle) ;
setP ((385,48)
.. controls (385,21) and (406,0)
.. (433,0)
.. controls (459,0) and (480,21)
.. (480,48)
.. controls (480,75) and (459,95)
.. (433,95)
.. controls (406,95) and (385,75)
.. (385,48)
-- cycle) ;
setP ((140,48)
.. controls (140,21) and (161,0)
.. (188,0)
.. controls (214,0) and (235,21)
.. (235,48)
.. controls (235,75) and (214,95)
.. (188,95)
.. controls (161,95) and (140,75)
.. (140,48)
-- cycle) ;
setP ((585,405)
.. controls (601,451) and (601,479)
.. (571,479)
.. controls (554,479) and (537,478)
.. (523,471)
.. controls (540,505) and (534,531)
.. (495,531)
.. controls (488,531) and (474,529)
.. (460,523)
.. controls (456,548) and (439,579)
.. (391,579)
.. controls (367,579) and (330,575)
.. (324,535)
.. controls (298,550) and (258,543)
.. (244,509)
.. controls (229,542) and (201,554)
.. (155,554)
.. controls (112,554) and (70,518)
.. (93,459)
.. controls (84,465) and (68,470)
.. (47,470)
.. controls (36,470) and (31,460)
.. (30,446)
.. controls (29,433) and (32,417)
.. (35,405)
-- cycle) ;
endchar;

beginchar (182,760*FS#,412*FS#,0*FS#);
"partialdiff";
setP ((496,172)
-- (549,0)
-- (618,0)
-- (564,172)
-- (730,172)
-- (730,212)
-- (552,212)
-- (501,372)
-- (601,372)
-- (601,412)
-- (159,412)
-- (159,372)
-- (259,372)
-- (208,212)
-- (30,212)
-- (30,172)
-- (196,172)
-- (142,0)
-- (211,0)
-- (264,172)
-- cycle) ;
setP ((277,212)
-- (327,372)
-- (433,372)
-- (483,212)
-- cycle) ;
endchar;

beginchar (183,694*FS#,698*FS#,0*FS#);
"summation";
setP ((509,400)
-- (576,512)
.. controls (581,508) and (587,507)
.. (596,507)
.. controls (610,507) and (625,522)
.. (625,541)
.. controls (625,560) and (613,575)
.. (593,575)
.. controls (572,575) and (554,558)
.. (554,541)
-- (425,541)
-- (362,636)
.. controls (371,640) and (381,650)
.. (381,667)
.. controls (381,683) and (366,698)
.. (347,698)
.. controls (328,698) and (313,683)
.. (313,667)
.. controls (313,650) and (323,640)
.. (332,636)
-- (269,541)
-- (140,541)
.. controls (140,558) and (122,575)
.. (101,575)
.. controls (81,575) and (69,560)
.. (69,541)
.. controls (69,522) and (84,507)
.. (98,507)
.. controls (107,507) and (113,508)
.. (118,512)
-- (185,400)
-- (118,289)
.. controls (113,293) and (107,294)
.. (98,294)
.. controls (84,294) and (69,279)
.. (69,260)
.. controls (69,241) and (81,225)
.. (101,225)
.. controls (122,225) and (140,243)
.. (140,260)
-- (269,260)
-- (332,165)
.. controls (323,161) and (313,151)
.. (313,133)
.. controls (313,117) and (328,103)
.. (347,103)
.. controls (366,103) and (381,117)
.. (381,133)
.. controls (381,151) and (371,161)
.. (362,165)
-- (425,260)
-- (554,260)
.. controls (554,243) and (572,225)
.. (593,225)
.. controls (613,225) and (625,241)
.. (625,260)
.. controls (625,279) and (610,294)
.. (596,294)
.. controls (587,294) and (581,293)
.. (576,289)
-- cycle) ;
endchar;

beginchar (184,1200*FS#,1000*FS#,200*FS#);
"product";
setP ((1200,389)
-- (1200,409)
-- (883,409)
.. controls (880,559) and (762,678)
.. (610,682)
-- (610,1000)
-- (590,1000)
-- (590,682)
.. controls (438,678) and (320,559)
.. (317,409)
-- (0,409)
-- (0,389)
-- (317,389)
.. controls (321,240) and (440,120)
.. (590,116)
-- (590,-200)
-- (610,-200)
-- (610,116)
.. controls (760,120) and (879,240)
.. (883,389)
-- cycle) ;
setP ((590,136)
.. controls (450,139) and (340,250)
.. (337,389)
-- (590,389)
-- cycle) ;
setP ((610,389)
-- (863,389)
.. controls (860,250) and (750,139)
.. (610,136)
-- cycle) ;
setP ((610,662)
.. controls (752,659) and (861,549)
.. (863,409)
-- (610,409)
-- cycle) ;
setP ((590,409)
-- (337,409)
.. controls (339,549) and (448,659)
.. (590,662)
-- cycle) ;
endchar;

beginchar (185,1072*FS#,919*FS#,121*FS#);
"pi";
setP ((0,-74)
.. controls (0,-124) and (21,-130)
.. (58,-112)
-- (1044,374)
.. controls (1082,393) and (1083,413)
.. (1044,432)
-- (58,910)
.. controls (21,928) and (0,922)
.. (0,872)
-- cycle) ;
setP ((30,857)
.. controls (30,880) and (51,880)
.. (67,872)
-- (993,424)
.. controls (1024,409) and (1024,397)
.. (993,382)
-- (67,-74)
.. controls (51,-82) and (30,-82)
.. (30,-59)
-- cycle) ;
endchar;

beginchar (186,520*FS#,750*FS#,0*FS#);
"integral";
setP ((328,713)
-- (301,631)
-- (212,631)
-- (286,576)
-- (258,490)
-- (328,543)
-- (400,490)
-- (373,576)
-- (444,631)
-- (355,631)
-- cycle) ;
setP ((420,0)
-- (420,320)
-- (275,320)
-- (275,381)
.. controls (315,384) and (353,406)
.. (367,432)
.. controls (340,423) and (308,418)
.. (283,418)
.. controls (208,418) and (147,491)
.. (147,583)
.. controls (147,675) and (208,748)
.. (254,748)
-- (254,750)
.. controls (157,748) and (76,667)
.. (76,564)
.. controls (76,465) and (149,388)
.. (245,381)
-- (245,320)
-- (100,320)
-- (100,0)
-- cycle) ;
endchar;

beginchar (187,857*FS#,543*FS#,0*FS#);
"ordfeminine";
setP ((275,0)
.. controls (305,0) and (336,22)
.. (350,55)
.. controls (364,22) and (395,0)
.. (425,0)
-- (574,0)
.. controls (605,0) and (644,14)
.. (666,34)
-- (758,126)
-- (758,190)
.. controls (758,207) and (732,212)
.. (712,212)
-- (712,232)
.. controls (712,242) and (702,242)
.. (688,241)
-- (545,229)
-- (517,289)
-- (827,517)
-- (810,543)
-- (499,314)
-- (333,314)
-- (322,337)
-- (249,337)
-- (249,305)
.. controls (206,305) and (168,287)
.. (165,261)
-- (159,200)
-- (44,180)
.. controls (26,177) and (22,137)
.. (32,112)
-- (62,34)
.. controls (69,16) and (112,0)
.. (137,0)
-- cycle) ;
endchar;

beginchar (188,333*FS#,677*FS#,0*FS#);
"ordmasculine";
setP ((124,514)
.. controls (133,504) and (130,489)
.. (129,477)
.. controls (105,473) and (89,475)
.. (83,465)
-- (37,391)
.. controls (32,382) and (33,375)
.. (36,368)
-- (93,290)
-- (62,227)
-- (87,220)
-- (79,146)
-- (95,48)
-- (62,31)
.. controls (56,27) and (41,28)
.. (41,13)
.. controls (41,6) and (50,0)
.. (61,0)
.. controls (76,0) and (87,6)
.. (92,10)
-- (105,16)
-- (111,14)
-- (128,23)
-- (129,41)
-- (130,48)
-- (130,154)
-- (152,244)
-- (154,244)
-- (178,155)
-- (165,53)
-- (171,49)
-- (172,27)
-- (183,21)
-- (189,23)
-- (204,10)
.. controls (205,9) and (222,0)
.. (233,0)
.. controls (245,0) and (252,4)
.. (252,13)
.. controls (252,23) and (241,26)
.. (236,31)
-- (207,57)
-- (230,147)
-- (208,260)
-- (224,264)
-- (210,322)
-- (212,345)
-- (235,345)
.. controls (248,345) and (255,355)
.. (253,365)
-- (235,451)
.. controls (232,464) and (220,469)
.. (216,473)
-- (243,527)
-- (259,527)
-- (312,638)
.. controls (320,654) and (324,669)
.. (321,677)
.. controls (311,673) and (305,657)
.. (296,640)
-- (245,545)
-- (227,545)
-- (193,477)
-- (174,477)
.. controls (172,493) and (172,504)
.. (179,514)
-- (194,518)
-- (194,543)
.. controls (194,559) and (188,578)
.. (152,578)
.. controls (115,578) and (109,559)
.. (109,543)
-- (109,518)
-- cycle) ;
setP ((69,380)
-- (90,414)
.. controls (93,394) and (93,368)
.. (88,343)
-- cycle) ;
endchar;

beginchar (189,700*FS#,456*FS#,0*FS#);
"Omega";
setP ((660,0)
-- (660,456)
-- (40,456)
-- (40,0)
-- cycle) ;
setP ((610,426)
-- (384,200)
.. controls (359,175) and (341,175)
.. (316,200)
-- (90,426)
-- cycle) ;
setP ((90,30)
-- (268,208)
.. controls (303,173) and (326,149)
.. (350,149)
.. controls (374,149) and (397,173)
.. (432,208)
-- (610,30)
-- cycle) ;
setP ((70,406)
-- (248,228)
-- (70,50)
-- cycle) ;
setP ((630,406)
-- (630,50)
-- (452,228)
-- cycle) ;
endchar;

beginchar (190,500*FS#,458*FS#,0*FS#);
"ae";
setP ((250,271)
-- (64,458)
-- (43,436)
-- (229,250)
-- (43,64)
-- (64,43)
-- (250,229)
-- (436,43)
-- (457,64)
-- (271,250)
-- (457,436)
-- (436,458)
-- cycle) ;
endchar;

beginchar (191,800*FS#,800*FS#,0*FS#);
"oslash";
setP ((234,800)
-- (0,566)
-- (0,235)
-- (234,0)
-- (566,0)
-- (800,235)
-- (800,566)
-- (566,800)
-- cycle) ;
setP ((553,770)
-- (770,554)
-- (770,247)
-- (553,30)
-- (246,30)
-- (30,247)
-- (30,554)
-- (246,770)
-- cycle) ;
endchar;

beginchar (192,696*FS#,718*FS#,0*FS#);
"questiondown";
setP ((592,607)
-- (556,642)
-- (460,546)
.. controls (437,570) and (404,582)
.. (373,582)
-- (373,718)
-- (323,718)
-- (323,582)
.. controls (293,582) and (254,572)
.. (234,552)
-- (138,647)
-- (103,612)
-- (198,516)
.. controls (170,488) and (167,447)
.. (166,425)
-- (30,425)
-- (30,375)
-- (166,375)
.. controls (167,340) and (178,312)
.. (203,289)
-- (107,193)
-- (143,157)
-- (239,253)
.. controls (262,231) and (293,218)
.. (323,218)
-- (323,82)
-- (373,82)
-- (373,218)
.. controls (403,219) and (433,234)
.. (457,258)
-- (552,162)
-- (588,198)
-- (492,294)
.. controls (512,316) and (530,340)
.. (530,375)
-- (666,375)
-- (666,425)
-- (530,425)
.. controls (530,447) and (519,488)
.. (495,511)
-- cycle) ;
setP ((216,400)
.. controls (216,474) and (274,532)
.. (348,532)
.. controls (422,532) and (480,474)
.. (480,400)
.. controls (480,326) and (422,268)
.. (348,268)
.. controls (274,268) and (216,326)
.. (216,400)
-- cycle) ;
endchar;

beginchar (193,560*FS#,650*FS#,0*FS#);
"exclamdown";
setP ((30,400)
.. controls (30,260) and (140,150)
.. (280,150)
.. controls (420,150) and (530,260)
.. (530,400)
.. controls (530,540) and (420,650)
.. (280,650)
.. controls (140,650) and (30,540)
.. (30,400)
-- cycle) ;
endchar;

beginchar (194,820*FS#,1000*FS#,200*FS#);
"logicalnot";
setP ((0,-129)
.. controls (0,-165) and (30,-200)
.. (60,-200)
-- (760,-200)
.. controls (790,-200) and (820,-165)
.. (820,-129)
-- (820,929)
.. controls (820,965) and (790,1002)
.. (760,1000)
-- (60,1000)
.. controls (30,1000) and (0,965)
.. (0,929)
-- cycle) ;
setP ((30,910)
.. controls (30,944) and (50,970)
.. (78,970)
-- (742,970)
.. controls (770,971) and (790,944)
.. (790,910)
-- (790,-111)
.. controls (790,-145) and (770,-170)
.. (742,-170)
-- (78,-170)
.. controls (50,-170) and (30,-145)
.. (30,-111)
-- cycle) ;
endchar;

beginchar (195,520*FS#,750*FS#,0*FS#);
"radical";
setP ((260,750)
-- (195,643)
-- (72,643)
-- (135,536)
-- (72,429)
-- (196,429)
-- (260,320)
-- (326,429)
-- (448,429)
-- (385,536)
-- (448,643)
-- (326,643)
-- cycle) ;
setP ((100,0)
-- (420,0)
-- (420,320)
-- (100,320)
-- cycle) ;
setP ((260,708)
-- (297,643)
-- (223,643)
-- cycle) ;
setP ((335,623)
-- (412,623)
-- (373,559)
-- cycle) ;
setP ((373,513)
-- (410,449)
-- (336,449)
-- cycle) ;
setP ((299,429)
-- (260,366)
-- (225,429)
-- cycle) ;
setP ((186,449)
-- (111,449)
-- (148,513)
-- cycle) ;
setP ((148,559)
-- (110,623)
-- (187,623)
-- cycle) ;
setP ((213,623)
-- (309,623)
-- (360,536)
-- (310,449)
-- (212,449)
-- (161,536)
-- cycle) ;
endchar;

beginchar (196,944*FS#,489*FS#,0*FS#);
"florin";
setP ((570,377)
-- (331,377)
-- (350,437)
-- (341,454)
-- (351,463)
-- (415,463)
-- (415,489)
-- (338,489)
-- (308,462)
-- (326,436)
-- (283,307)
.. controls (262,321) and (236,332)
.. (196,332)
.. controls (103,332) and (30,259)
.. (30,166)
.. controls (30,73) and (103,0)
.. (196,0)
.. controls (282,0) and (362,76)
.. (362,166)
.. controls (362,230) and (337,273)
.. (303,298)
-- (313,325)
-- (481,139)
.. controls (476,130) and (476,120)
.. (480,112)
.. controls (485,103) and (493,97)
.. (505,96)
-- (511,59)
-- (498,55)
-- (500,39)
-- (544,48)
-- (541,64)
-- (528,62)
-- (520,100)
.. controls (526,107) and (523,106)
.. (524,114)
-- (583,124)
.. controls (605,44) and (666,0)
.. (748,0)
.. controls (840,0) and (914,73)
.. (914,166)
.. controls (914,259) and (840,332)
.. (748,332)
.. controls (699,334) and (668,316)
.. (654,305)
-- (600,369)
-- (606,391)
.. controls (618,391) and (636,391)
.. (647,402)
-- (663,420)
.. controls (667,426) and (663,434)
.. (657,434)
-- (523,424)
.. controls (514,423) and (513,418)
.. (516,413)
.. controls (526,399) and (563,394)
.. (575,391)
-- cycle) ;
setP ((589,338)
-- (630,288)
.. controls (600,261) and (575,202)
.. (577,152)
-- (526,143)
-- cycle) ;
setP ((475,191)
-- (484,191)
-- (484,171)
-- (320,351)
-- (566,351)
-- (506,168)
-- (499,168)
-- (499,191)
-- (508,191)
-- (508,203)
-- (475,203)
-- cycle) ;
setP ((276,216)
-- (292,262)
.. controls (310,244) and (328,211)
.. (328,166)
.. controls (328,91) and (265,32)
.. (196,34)
.. controls (122,34) and (64,91)
.. (64,166)
.. controls (64,241) and (122,298)
.. (196,298)
.. controls (239,297) and (263,287)
.. (273,276)
-- (257,229)
-- (201,176)
-- (190,180)
.. controls (177,180) and (167,172)
.. (167,158)
.. controls (167,146) and (177,138)
.. (188,138)
.. controls (200,138) and (205,145)
.. (207,150)
-- cycle) ;
setP ((708,192)
.. controls (716,182) and (717,176)
.. (708,174)
-- (611,158)
.. controls (611,204) and (627,243)
.. (652,262)
-- cycle) ;
setP ((675,278)
.. controls (690,290) and (711,298)
.. (748,298)
.. controls (822,298) and (880,241)
.. (880,166)
.. controls (880,91) and (822,34)
.. (748,34)
.. controls (675,37) and (626,84)
.. (615,130)
-- (745,152)
.. controls (757,155) and (763,158)
.. (763,164)
.. controls (763,169) and (754,178)
.. (751,183)
-- cycle) ;
endchar;

beginchar (197,424*FS#,739*FS#,0*FS#);
"approxequal";
setP ((300,530)
.. controls (290,566) and (288,591)
.. (288,619)
-- (288,683)
.. controls (296,685) and (303,688)
.. (309,692)
-- (309,716)
.. controls (309,731) and (256,739)
.. (212,739)
.. controls (168,739) and (115,731)
.. (115,717)
-- (115,692)
.. controls (121,688) and (128,685)
.. (136,683)
-- (136,619)
.. controls (136,591) and (134,566)
.. (124,530)
-- (38,211)
.. controls (33,192) and (30,173)
.. (30,160)
.. controls (30,146) and (37,137)
.. (52,122)
.. controls (67,107) and (111,61)
.. (212,61)
.. controls (313,61) and (357,107)
.. (372,122)
.. controls (387,137) and (394,146)
.. (394,160)
.. controls (394,173) and (391,192)
.. (386,211)
-- cycle) ;
setP ((263,611)
.. controls (263,586) and (263,563)
.. (272,530)
-- (347,239)
.. controls (352,221) and (361,198)
.. (361,181)
.. controls (361,168) and (358,149)
.. (337,131)
.. controls (319,120) and (291,91)
.. (212,91)
.. controls (133,91) and (105,120)
.. (87,131)
.. controls (66,149) and (63,168)
.. (63,181)
.. controls (63,198) and (72,221)
.. (77,239)
-- (152,530)
.. controls (161,563) and (161,586)
.. (161,611)
-- (161,689)
.. controls (155,691) and (150,694)
.. (145,698)
-- (145,707)
.. controls (145,717) and (183,720)
.. (212,720)
.. controls (241,720) and (279,717)
.. (279,707)
-- (279,698)
.. controls (274,694) and (269,691)
.. (263,689)
-- cycle) ;
endchar;

beginchar (198,810*FS#,814*FS#,14*FS#);
"Delta";
setP ((521,-14)
-- (521,54)
-- (445,114)
-- (445,328)
-- (780,207)
-- (780,291)
-- (445,499)
-- (445,776)
.. controls (445,804) and (422,814)
.. (405,814)
.. controls (388,814) and (365,804)
.. (365,776)
-- (365,499)
-- (30,291)
-- (30,207)
-- (365,328)
-- (365,114)
-- (289,54)
-- (289,-14)
-- (405,39)
-- cycle) ;
endchar;

beginchar (199,900*FS#,717*FS#,0*FS#);
"guillemotleft";
setP ((763,491)
-- (631,624)
-- (631,315)
-- (229,717)
-- (130,618)
-- (532,216)
-- (223,216)
-- (356,84)
-- (763,84)
-- cycle) ;
endchar;

beginchar (200,900*FS#,688*FS#,0*FS#);
"guillemotright";
setP ((859,400)
-- (571,688)
-- (384,688)
-- (602,470)
-- (34,470)
-- (34,330)
-- (602,330)
-- (384,112)
-- (571,112)
-- cycle) ;
endchar;

beginchar (201,620*FS#,679*FS#,0*FS#);
"ellipsis";
setP ((590,122)
-- (311,679)
-- (30,122)
-- cycle) ;
setP ((64,142)
-- (310,635)
-- (556,142)
-- cycle) ;
setP ((255,302)
.. controls (255,271) and (279,247)
.. (310,247)
.. controls (341,247) and (365,271)
.. (365,302)
.. controls (365,333) and (341,357)
.. (310,357)
.. controls (279,357) and (255,333)
.. (255,302)
-- cycle) ;
endchar;

beginchar (202,1092*FS#,946*FS#,147*FS#);
"nbspace";
setP ((17,436)
.. controls (-5,413) and (-5,385)
.. (17,364)
-- (512,-131)
.. controls (533,-152) and (561,-152)
.. (582,-131)
-- (1077,364)
.. controls (1099,385) and (1099,414)
.. (1077,435)
-- (582,930)
.. controls (561,951) and (533,952)
.. (512,930)
-- cycle) ;
setP ((0,0)
-- cycle) ;
endchar;

beginchar (203,960*FS#,871*FS#,71*FS#);
"Agrave";
setP ((150,871)
.. controls (37,871) and (-7,835)
.. (1,757)
-- (88,62)
.. controls (99,-33) and (141,-71)
.. (222,-71)
-- (738,-71)
.. controls (819,-71) and (859,-33)
.. (872,62)
-- (958,757)
.. controls (968,835) and (923,871)
.. (810,871)
-- cycle) ;
endchar;

beginchar (204,1020*FS#,810*FS#,10*FS#);
"Atilde";
setP ((60,810)
.. controls (30,810) and (0,780)
.. (0,750)
-- (0,50)
.. controls (0,20) and (30,-8)
.. (60,-10)
-- (960,-10)
.. controls (990,-10) and (1020,20)
.. (1020,50)
-- (1020,750)
.. controls (1020,780) and (990,810)
.. (960,810)
-- cycle) ;
endchar;

beginchar (205,854*FS#,880*FS#,80*FS#);
"Otilde";
setP ((0,122)
.. controls (0,-80) and (189,-80)
.. (426,-80)
.. controls (665,-80) and (854,-80)
.. (854,122)
-- (854,272)
.. controls (854,441) and (818,594)
.. (722,679)
.. controls (584,801) and (491,851)
.. (426,880)
.. controls (362,851) and (270,801)
.. (131,679)
.. controls (35,594) and (0,441)
.. (0,272)
-- cycle) ;
endchar;

beginchar (206,560*FS#,500*FS#,0*FS#);
"OE";
setP ((530,0)
-- (530,500)
-- (30,500)
-- (30,0)
-- cycle) ;
setP ((500,30)
-- (413,30)
-- (413,470)
-- (500,470)
-- cycle) ;
setP ((265,30)
-- (177,30)
-- (177,470)
-- (265,470)
-- cycle) ;
setP ((383,30)
-- (295,30)
-- (295,470)
-- (383,470)
-- cycle) ;
setP ((147,30)
-- (60,30)
-- (60,470)
-- (147,470)
-- cycle) ;
endchar;

beginchar (207,686*FS#,750*FS#,0*FS#);
"oe";
setP ((626,0)
-- (626,50)
-- (50,50)
-- (50,0)
-- cycle) ;
setP ((338,750)
-- (30,482)
-- (646,482)
-- cycle) ;
setP ((533,80)
-- (533,181)
.. controls (533,236) and (626,221)
.. (626,320)
.. controls (626,397) and (573,452)
.. (486,452)
-- (191,452)
.. controls (104,452) and (50,397)
.. (50,320)
.. controls (50,221) and (143,236)
.. (143,181)
-- (143,80)
-- cycle) ;
setP ((193,130)
-- (193,185)
.. controls (193,233) and (295,200)
.. (295,304)
.. controls (295,341) and (265,377)
.. (219,377)
.. controls (173,377) and (150,343)
.. (150,311)
.. controls (150,290) and (161,281)
.. (174,281)
.. controls (186,281) and (200,290)
.. (200,304)
.. controls (200,317) and (203,334)
.. (223,334)
.. controls (239,334) and (245,318)
.. (245,299)
.. controls (245,271) and (218,248)
.. (180,248)
.. controls (137,248) and (100,280)
.. (100,323)
.. controls (100,366) and (137,399)
.. (180,402)
-- (497,402)
.. controls (540,399) and (576,366)
.. (576,323)
.. controls (576,280) and (540,248)
.. (497,248)
.. controls (460,248) and (431,271)
.. (431,299)
.. controls (431,318) and (438,334)
.. (454,334)
.. controls (475,334) and (476,317)
.. (476,304)
.. controls (476,290) and (491,281)
.. (504,281)
.. controls (516,281) and (526,290)
.. (526,311)
.. controls (526,343) and (505,377)
.. (459,377)
.. controls (413,377) and (381,341)
.. (381,304)
.. controls (381,200) and (483,233)
.. (483,185)
-- (483,130)
-- cycle) ;
endchar;

beginchar (208,807*FS#,668*FS#,0*FS#);
"endash";
setP ((432,397)
-- (509,475)
.. controls (574,409) and (691,382)
.. (753,444)
.. controls (798,489) and (771,553)
.. (739,586)
-- (681,644)
.. controls (660,664) and (634,656)
.. (619,641)
-- (542,564)
-- (509,596)
.. controls (489,617) and (502,650)
.. (516,668)
.. controls (502,665) and (479,654)
.. (468,632)
.. controls (453,606) and (458,578)
.. (477,560)
-- (508,530)
-- (404,426)
-- (300,530)
-- (329,561)
.. controls (349,579) and (354,607)
.. (339,632)
.. controls (327,655) and (305,665)
.. (291,668)
.. controls (305,651) and (318,617)
.. (298,597)
-- (265,564)
-- (189,641)
.. controls (173,656) and (146,665)
.. (127,644)
-- (69,586)
.. controls (35,554) and (9,489)
.. (54,445)
.. controls (116,383) and (233,409)
.. (298,475)
-- (375,397)
-- (111,133)
.. controls (168,141) and (209,175)
.. (252,218)
-- (404,369)
-- (556,216)
.. controls (598,175) and (640,141)
.. (696,133)
-- cycle) ;
setP ((624,588)
.. controls (640,604) and (662,609)
.. (680,591)
-- (709,562)
.. controls (729,542) and (750,494)
.. (728,473)
.. controls (668,413) and (571,466)
.. (537,501)
-- cycle) ;
setP ((272,501)
.. controls (236,467) and (139,414)
.. (79,475)
.. controls (58,496) and (78,543)
.. (99,564)
-- (128,593)
.. controls (146,610) and (168,605)
.. (185,588)
-- cycle) ;
endchar;

beginchar (209,1260*FS#,553*FS#,0*FS#);
"emdash";
setP ((1230,0)
-- (1230,228)
-- (1005,228)
-- (1005,83)
-- (645,83)
-- (645,358)
-- (759,455)
-- (615,553)
-- (615,83)
-- (255,83)
-- (255,228)
-- (30,228)
-- (30,0)
-- cycle) ;
endchar;

beginchar (210,900*FS#,717*FS#,0*FS#);
"quotedblleft";
setP ((130,84)
-- (537,84)
-- (670,216)
-- (361,216)
-- (763,618)
-- (664,717)
-- (262,315)
-- (262,624)
-- (130,491)
-- cycle) ;
endchar;

beginchar (211,900*FS#,688*FS#,0*FS#);
"quotedblright";
setP ((34,400)
-- (322,112)
-- (509,112)
-- (291,330)
-- (859,330)
-- (859,470)
-- (291,470)
-- (509,688)
-- (322,688)
-- cycle) ;
endchar;

beginchar (212,900*FS#,813*FS#,12*FS#);
"quoteleft";
setP ((447,-12)
-- (735,276)
-- (735,463)
-- (517,245)
-- (517,813)
-- (377,813)
-- (377,245)
-- (159,463)
-- (159,276)
-- cycle) ;
endchar;

beginchar (213,900*FS#,813*FS#,12*FS#);
"quoteright";
setP ((447,813)
-- (159,525)
-- (159,338)
-- (377,556)
-- (377,-12)
-- (517,-12)
-- (517,556)
-- (735,338)
-- (735,525)
-- cycle) ;
endchar;

beginchar (214,655*FS#,590*FS#,0*FS#);
"divide";
setP ((435,380)
-- (575,210)
-- (620,210)
-- (465,400)
-- (620,590)
-- (575,590)
-- (435,420)
-- (35,420)
-- (35,380)
-- cycle) ;
endchar;

beginchar (215,520*FS#,750*FS#,0*FS#);
"lozenge";
setP ((420,0)
-- (420,320)
-- (275,320)
-- (275,509)
.. controls (363,509) and (433,555)
.. (458,641)
.. controls (338,560) and (288,628)
.. (262,750)
-- (260,750)
.. controls (234,628) and (184,560)
.. (64,641)
.. controls (89,556) and (157,509)
.. (245,509)
-- (245,320)
-- (100,320)
-- (100,0)
-- cycle) ;
endchar;

beginchar (216,800*FS#,800*FS#,0*FS#);
"ydieresis";
setP ((234,800)
-- (0,566)
-- (0,235)
-- (234,0)
-- (566,0)
-- (800,235)
-- (800,566)
-- (566,800)
-- cycle) ;
endchar;

beginchar (217,1063*FS#,921*FS#,122*FS#);
"Ydieresis";
setP ((30,748)
.. controls (58,736) and (97,664)
.. (97,608)
.. controls (97,545) and (0,460)
.. (0,299)
.. controls (0,83) and (151,-88)
.. (265,-88)
.. controls (315,-88) and (344,-79)
.. (367,-69)
.. controls (391,-60) and (409,-50)
.. (425,-50)
.. controls (456,-50) and (499,-84)
.. (531,-122)
.. controls (563,-84) and (607,-50)
.. (638,-50)
.. controls (654,-50) and (672,-60)
.. (696,-69)
.. controls (719,-79) and (747,-88)
.. (798,-88)
.. controls (912,-88) and (1063,83)
.. (1063,299)
.. controls (1063,460) and (966,545)
.. (966,608)
.. controls (967,664) and (1006,736)
.. (1034,748)
-- (845,921)
.. controls (790,862) and (737,824)
.. (689,824)
.. controls (637,824) and (557,862)
.. (531,921)
.. controls (505,862) and (427,824)
.. (375,824)
.. controls (327,824) and (274,862)
.. (218,921)
-- cycle) ;
endchar;

beginchar (218,695*FS#,717*FS#,0*FS#);
"fraction";
setP ((30,400)
.. controls (30,223) and (170,83)
.. (347,83)
.. controls (524,83) and (665,223)
.. (665,400)
.. controls (665,577) and (524,717)
.. (347,717)
.. controls (170,717) and (30,577)
.. (30,400)
-- cycle) ;
endchar;

beginchar (219,1005*FS#,921*FS#,121*FS#);
"currency";
setP ((503,-121)
.. controls (597,-121) and (767,-18)
.. (853,90)
.. controls (945,206) and (1005,346)
.. (1005,508)
.. controls (1005,663) and (930,835)
.. (850,921)
.. controls (793,882) and (735,860)
.. (677,860)
.. controls (619,860) and (561,882)
.. (503,921)
.. controls (446,882) and (387,860)
.. (329,860)
.. controls (271,860) and (213,882)
.. (154,921)
.. controls (75,835) and (0,663)
.. (0,508)
.. controls (0,346) and (59,206)
.. (153,90)
.. controls (238,-18) and (408,-121)
.. (503,-121)
-- cycle) ;
endchar;

beginchar (220,820*FS#,1000*FS#,200*FS#);
"guilsinglleft";
setP ((0,-129)
.. controls (0,-165) and (30,-200)
.. (60,-200)
-- (760,-200)
.. controls (790,-200) and (820,-165)
.. (820,-129)
-- (820,929)
.. controls (820,965) and (790,1002)
.. (760,1000)
-- (60,1000)
.. controls (30,1000) and (0,965)
.. (0,929)
-- cycle) ;
endchar;

beginchar (221,970*FS#,885*FS#,85*FS#);
"guilsinglright";
setP ((0,400)
.. controls (0,129) and (213,-85)
.. (485,-85)
.. controls (757,-85) and (970,129)
.. (970,400)
.. controls (970,671) and (757,885)
.. (485,885)
.. controls (213,885) and (0,671)
.. (0,400)
-- cycle) ;
endchar;

beginchar (222,1442*FS#,799*FS#,0*FS#);
"fi";
setP ((0,411)
.. controls (0,194) and (311,22)
.. (721,22)
.. controls (1125,22) and (1442,194)
.. (1442,411)
.. controls (1442,628) and (1125,799)
.. (721,799)
.. controls (318,799) and (0,628)
.. (0,411)
-- cycle) ;
endchar;

beginchar (223,1054*FS#,700*FS#,0*FS#);
"fl";
setP ((896,0)
-- (1054,154)
-- (1052,156)
-- (876,156)
-- (1044,516)
-- (1042,518)
-- (740,270)
-- (732,366)
-- (612,180)
-- (592,476)
-- (494,296)
-- (252,700)
-- (250,698)
-- (274,276)
-- (186,326)
-- (182,134)
-- (2,232)
-- (0,230)
-- (173,0)
-- cycle) ;
setP ((184,20)
-- (71,169)
-- (73,169)
-- (200,103)
-- (203,293)
-- (297,239)
-- (273,624)
-- (275,624)
-- (495,257)
-- (578,409)
-- (598,123)
-- (718,307)
-- (726,232)
-- (988,448)
-- (988,450)
-- (990,448)
-- (844,136)
-- (1007,136)
-- (888,20)
-- cycle) ;
endchar;

beginchar (224,800*FS#,800*FS#,0*FS#);
"daggerdbl";
setP ((50,800)
.. controls (20,800) and (0,780)
.. (0,750)
-- (0,50)
.. controls (0,20) and (20,0)
.. (50,0)
-- (750,0)
.. controls (780,0) and (800,20)
.. (800,43)
-- (800,750)
.. controls (800,780) and (780,800)
.. (750,800)
-- cycle) ;
endchar;

beginchar (225,700*FS#,921*FS#,122*FS#);
"periodcentered";
setP ((700,856)
-- (568,921)
.. controls (529,899) and (496,884)
.. (459,884)
.. controls (423,884) and (371,899)
.. (350,921)
.. controls (329,899) and (277,884)
.. (241,884)
.. controls (205,884) and (171,899)
.. (132,921)
-- (0,856)
-- (0,606)
.. controls (16,555) and (34,503)
.. (34,451)
.. controls (34,425) and (30,399)
.. (23,373)
.. controls (17,347) and (8,322)
.. (0,296)
.. controls (0,196) and (41,101)
.. (106,21)
.. controls (166,-52) and (285,-122)
.. (350,-122)
.. controls (416,-122) and (534,-52)
.. (594,21)
.. controls (658,101) and (700,196)
.. (700,296)
.. controls (684,347) and (666,399)
.. (666,451)
.. controls (666,477) and (671,503)
.. (677,529)
.. controls (684,555) and (692,581)
.. (700,606)
-- cycle) ;
endchar;

beginchar (226,700*FS#,800*FS#,0*FS#);
"quotesinglbase";
setP ((0,800)
-- (0,300)
.. controls (0,110) and (180,0)
.. (350,0)
.. controls (520,0) and (700,110)
.. (700,300)
-- (700,800)
-- cycle) ;
endchar;

beginchar (227,695*FS#,584*FS#,0*FS#);
"quotedblbase";
setP ((531,400)
.. controls (531,508) and (456,584)
.. (348,584)
.. controls (240,584) and (164,508)
.. (164,400)
.. controls (164,292) and (240,216)
.. (348,216)
.. controls (456,216) and (531,292)
.. (531,400)
-- cycle) ;
endchar;

beginchar (228,694*FS#,697*FS#,0*FS#);
"perthousand";
setP ((347,697)
-- (260,471)
-- (30,471)
-- (206,329)
-- (141,102)
-- (347,236)
-- (553,102)
-- (478,329)
-- (664,471)
-- (435,471)
-- cycle) ;
setP ((416,451)
-- (595,451)
-- (450,340)
-- (510,157)
-- (347,267)
-- (184,157)
-- (237,340)
-- (99,451)
-- (279,451)
-- (347,634)
-- cycle) ;
setP ((347,528)
-- (308,421)
-- (201,421)
-- (284,358)
-- (252,252)
-- (347,317)
-- (442,252)
-- (405,358)
-- (493,421)
-- (386,421)
-- cycle) ;
endchar;

beginchar (229,694*FS#,697*FS#,0*FS#);
"Acircumflex";
setP ((347,697)
-- (265,473)
-- (30,473)
-- (222,336)
-- (135,104)
-- (347,249)
-- (559,104)
-- (475,336)
-- (664,473)
-- (430,473)
-- cycle) ;
setP ((250,367)
.. controls (250,421) and (293,465)
.. (347,465)
.. controls (401,465) and (444,421)
.. (444,367)
.. controls (444,312) and (401,269)
.. (347,269)
.. controls (293,269) and (250,312)
.. (250,367)
-- cycle) ;
endchar;

beginchar (230,695*FS#,584*FS#,0*FS#);
"Ecircumflex";
setP ((531,400)
.. controls (531,508) and (456,584)
.. (348,584)
.. controls (240,584) and (164,508)
.. (164,400)
.. controls (164,292) and (240,216)
.. (348,216)
.. controls (456,216) and (531,292)
.. (531,400)
-- cycle) ;
setP ((501,400)
.. controls (501,309) and (438,246)
.. (348,246)
.. controls (257,246) and (194,309)
.. (194,400)
.. controls (194,491) and (257,554)
.. (348,554)
.. controls (438,554) and (501,491)
.. (501,400)
-- cycle) ;
endchar;

beginchar (231,907*FS#,841*FS#,52*FS#);
"Aacute";
setP ((849,-52)
.. controls (878,-52) and (907,-23)
.. (907,7)
-- (907,538)
.. controls (907,572) and (888,593)
.. (862,609)
-- (478,833)
.. controls (459,844) and (448,844)
.. (429,833)
-- (46,609)
.. controls (19,593) and (0,572)
.. (0,538)
-- (0,7)
.. controls (0,-23) and (29,-52)
.. (58,-52)
-- cycle) ;
setP ((71,-22)
.. controls (44,-22) and (30,-8)
.. (30,20)
-- (30,533)
.. controls (30,565) and (48,580)
.. (73,595)
-- (431,804)
.. controls (449,814) and (459,814)
.. (477,804)
-- (835,595)
.. controls (859,580) and (877,565)
.. (877,533)
-- (877,20)
.. controls (877,-8) and (863,-22)
.. (836,-22)
-- cycle) ;
endchar;

beginchar (232,1000*FS#,894*FS#,94*FS#);
"Edieresis";
setP ((75,796)
.. controls (29,796) and (0,775)
.. (0,652)
.. controls (0,439) and (211,129)
.. (430,-66)
.. controls (471,-103) and (529,-103)
.. (570,-66)
.. controls (789,129) and (1000,439)
.. (1000,652)
.. controls (1000,775) and (971,796)
.. (925,796)
-- (629,796)
-- (629,859)
.. controls (629,881) and (615,894)
.. (593,894)
-- (407,894)
.. controls (384,894) and (371,881)
.. (371,859)
-- (371,796)
-- cycle) ;
setP ((401,766)
-- (401,841)
.. controls (401,857) and (408,864)
.. (425,864)
-- (575,864)
.. controls (591,864) and (599,857)
.. (599,841)
-- (599,766)
-- (899,766)
.. controls (942,766) and (970,741)
.. (970,637)
.. controls (970,465) and (773,156)
.. (563,-34)
.. controls (521,-72) and (479,-72)
.. (437,-34)
.. controls (227,156) and (30,465)
.. (30,637)
.. controls (30,741) and (57,766)
.. (100,766)
-- cycle) ;
endchar;

beginchar (233,434*FS#,840*FS#,40*FS#);
"Egrave";
setP ((404,-40)
-- (404,840)
-- (30,840)
-- (30,-40)
-- cycle) ;
setP ((117,130)
.. controls (117,186) and (161,230)
.. (217,230)
.. controls (273,230) and (317,186)
.. (317,130)
.. controls (317,74) and (273,30)
.. (217,30)
.. controls (161,30) and (117,74)
.. (117,130)
-- cycle) ;
setP ((117,400)
.. controls (117,456) and (161,500)
.. (217,500)
.. controls (273,500) and (317,456)
.. (317,400)
.. controls (317,344) and (273,300)
.. (217,300)
.. controls (161,300) and (117,344)
.. (117,400)
-- cycle) ;
setP ((117,670)
.. controls (117,726) and (161,770)
.. (217,770)
.. controls (273,770) and (317,726)
.. (317,670)
.. controls (317,614) and (273,570)
.. (217,570)
.. controls (161,570) and (117,614)
.. (117,670)
-- cycle) ;
endchar;

beginchar (234,450*FS#,649*FS#,6*FS#);
"Iacute";
setP ((39,293)
.. controls (39,255) and (68,176)
.. (171,175)
.. controls (144,194) and (104,224)
.. (94,274)
.. controls (92,291) and (88,313)
.. (89,338)
.. controls (90,364) and (93,390)
.. (99,409)
.. controls (58,376) and (39,331)
.. (39,293)
-- cycle) ;
setP ((402,273)
.. controls (424,353) and (387,454)
.. (347,487)
.. controls (356,439) and (355,401)
.. (353,382)
.. controls (351,349) and (312,291)
.. (284,259)
.. controls (273,247) and (251,213)
.. (251,199)
.. controls (251,190) and (248,184)
.. (251,175)
.. controls (283,192) and (317,192)
.. (344,205)
.. controls (363,214) and (396,244)
.. (402,273)
-- cycle) ;
setP ((394,23)
.. controls (410,23) and (420,38)
.. (420,52)
.. controls (420,67) and (414,83)
.. (402,83)
.. controls (388,83) and (375,67)
.. (375,49)
.. controls (375,38) and (378,23)
.. (394,23)
-- cycle) ;
setP ((80,24)
.. controls (80,42) and (73,55)
.. (55,55)
.. controls (38,55) and (30,42)
.. (30,24)
.. controls (30,6) and (38,-6)
.. (55,-6)
.. controls (73,-6) and (80,6)
.. (80,24)
-- cycle) ;
setP ((182,52)
.. controls (155,63) and (127,78)
.. (100,78)
-- (67,65)
.. controls (93,50) and (94,29)
.. (88,2)
-- cycle) ;
setP ((410,131)
.. controls (417,151) and (406,165)
.. (387,172)
-- (336,160)
.. controls (314,155) and (279,151)
.. (243,132)
.. controls (269,122) and (312,112)
.. (338,109)
-- cycle) ;
setP ((195,132)
.. controls (157,138) and (75,148)
.. (64,150)
.. controls (46,133) and (44,117)
.. (49,96)
.. controls (49,96) and (109,92)
.. (140,83)
.. controls (171,74) and (191,58)
.. (228,54)
.. controls (270,49) and (302,43)
.. (317,42)
.. controls (331,40) and (347,30)
.. (365,28)
.. controls (356,57) and (362,77)
.. (384,87)
-- (384,90)
.. controls (361,90) and (314,99)
.. (267,111)
.. controls (240,117) and (219,128)
.. (195,132)
-- cycle) ;
setP ((117,355)
.. controls (117,255) and (165,205)
.. (209,172)
.. controls (215,201) and (235,236)
.. (257,263)
.. controls (267,276) and (294,306)
.. (303,322)
.. controls (314,341) and (327,360)
.. (327,420)
.. controls (327,501) and (273,616)
.. (243,649)
.. controls (243,605) and (231,580)
.. (210,551)
.. controls (195,532) and (117,429)
.. (117,355)
-- cycle) ;
endchar;

beginchar (235,550*FS#,400*FS#,0*FS#);
"Icircumflex";
setP ((520,0)
-- (520,110)
-- (140,110)
-- (140,290)
-- (520,290)
-- (520,400)
-- (30,400)
-- (30,0)
-- cycle) ;
endchar;

beginchar (236,520*FS#,750*FS#,0*FS#);
"Idieresis";
setP ((245,750)
-- (245,215)
.. controls (139,211) and (60,165)
.. (60,108)
.. controls (60,48) and (146,0)
.. (260,0)
.. controls (372,0) and (460,48)
.. (460,108)
.. controls (460,165) and (380,212)
.. (275,215)
-- (275,499)
-- (420,625)
-- cycle) ;
setP ((275,185)
.. controls (363,182) and (430,149)
.. (430,108)
.. controls (430,65) and (355,30)
.. (260,30)
.. controls (163,30) and (90,65)
.. (90,108)
.. controls (90,148) and (156,182)
.. (245,185)
-- (245,100)
-- (275,100)
-- cycle) ;
endchar;

beginchar (237,548*FS#,649*FS#,0*FS#);
"Igrave";
setP ((515,197)
.. controls (520,207) and (514,210)
.. (507,214)
-- (475,231)
.. controls (490,263) and (518,327)
.. (518,425)
.. controls (518,522) and (425,649)
.. (274,649)
.. controls (123,649) and (30,522)
.. (30,425)
.. controls (30,327) and (58,263)
.. (73,231)
-- (41,214)
.. controls (34,210) and (28,207)
.. (33,197)
-- (53,157)
.. controls (56,151) and (60,148)
.. (67,152)
-- (150,196)
.. controls (158,200) and (158,206)
.. (154,214)
.. controls (143,235) and (110,307)
.. (110,363)
.. controls (110,420) and (130,579)
.. (274,579)
.. controls (418,579) and (438,420)
.. (438,363)
.. controls (438,307) and (405,235)
.. (394,214)
.. controls (390,206) and (390,200)
.. (398,196)
-- (481,152)
.. controls (488,148) and (492,151)
.. (495,157)
-- cycle) ;
endchar;

beginchar (238,600*FS#,600*FS#,0*FS#);
"Oacute";
setP ((225,500)
-- (125,600)
-- (75,550)
-- (155,470)
-- (155,130)
-- (75,50)
-- (125,0)
-- (225,100)
-- cycle) ;
setP ((375,100)
-- (475,0)
-- (525,50)
-- (445,130)
-- (445,470)
-- (525,550)
-- (475,600)
-- (375,500)
-- cycle) ;
endchar;

beginchar (239,655*FS#,590*FS#,0*FS#);
"Ocircumflex";
setP ((601,210)
.. controls (611,210) and (621,220)
.. (621,230)
-- (621,250)
.. controls (621,260) and (611,270)
.. (601,270)
-- (301,270)
.. controls (291,270) and (281,260)
.. (281,250)
-- (281,230)
.. controls (281,220) and (291,210)
.. (301,210)
-- cycle) ;
setP ((595,458)
.. controls (586,486) and (555,510)
.. (516,510)
-- (401,510)
-- (401,570)
-- (433,570)
.. controls (439,570) and (446,562)
.. (456,562)
-- (602,562)
.. controls (612,562) and (620,569)
.. (620,576)
.. controls (620,583) and (612,590)
.. (602,590)
-- (456,590)
.. controls (446,590) and (439,582)
.. (433,582)
-- (343,582)
.. controls (337,582) and (330,590)
.. (320,590)
-- (174,590)
.. controls (164,590) and (156,583)
.. (156,576)
.. controls (156,569) and (164,562)
.. (174,562)
-- (320,562)
.. controls (330,562) and (337,570)
.. (343,570)
-- (376,570)
-- (376,510)
-- (149,510)
.. controls (141,531) and (120,548)
.. (92,548)
.. controls (57,548) and (30,520)
.. (30,485)
.. controls (30,450) and (57,423)
.. (92,423)
.. controls (120,423) and (138,435)
.. (149,448)
-- (288,397)
-- (307,350)
.. controls (315,329) and (325,320)
.. (341,320)
-- (589,320)
.. controls (629,320) and (630,349)
.. (620,379)
-- cycle) ;
setP ((401,410)
-- (401,490)
-- (451,490)
-- (451,410)
-- cycle) ;
setP ((471,410)
-- (471,490)
-- (521,490)
-- (521,410)
-- cycle) ;
setP ((541,410)
-- (541,490)
.. controls (567,481) and (587,449)
.. (591,410)
-- cycle) ;
setP ((98,510)
.. controls (84,510) and (78,504)
.. (78,494)
.. controls (78,488) and (85,478)
.. (94,473)
-- (132,454)
.. controls (124,444) and (110,438)
.. (92,438)
.. controls (65,438) and (45,459)
.. (45,485)
.. controls (45,512) and (65,533)
.. (92,533)
.. controls (112,533) and (125,524)
.. (130,510)
-- cycle) ;
endchar;

beginchar (240,907*FS#,841*FS#,52*FS#);
"apple";
setP ((849,-52)
.. controls (878,-52) and (907,-23)
.. (907,7)
-- (907,538)
.. controls (907,572) and (888,593)
.. (862,609)
-- (478,833)
.. controls (459,844) and (448,844)
.. (429,833)
-- (46,609)
.. controls (19,593) and (0,572)
.. (0,538)
-- (0,7)
.. controls (0,-23) and (29,-52)
.. (58,-52)
-- cycle) ;
endchar;

beginchar (241,808*FS#,804*FS#,4*FS#);
"Ograve";
setP ((0,664)
-- (264,400)
-- (0,136)
-- (140,-4)
-- (404,260)
-- (668,-4)
-- (808,136)
-- (544,400)
-- (808,664)
-- (668,804)
-- (404,540)
-- (140,804)
-- cycle) ;
setP ((140,762)
-- (404,498)
-- (668,761)
-- (765,664)
-- (502,400)
-- (765,136)
-- (668,39)
-- (404,302)
-- (140,39)
-- (43,136)
-- (306,400)
-- (42,664)
-- cycle) ;
endchar;

beginchar (242,702*FS#,718*FS#,0*FS#);
"Uacute";
setP ((373,718)
-- (323,718)
-- (323,582)
.. controls (249,585) and (167,506)
.. (166,425)
-- (30,425)
-- (30,375)
-- (166,375)
.. controls (167,305) and (242,219)
.. (323,218)
-- (323,82)
-- (373,82)
-- (373,218)
.. controls (451,231) and (521,298)
.. (530,375)
-- (666,375)
-- (666,425)
-- (530,425)
.. controls (529,495) and (454,581)
.. (373,582)
-- cycle) ;
setP ((216,400)
.. controls (216,474) and (274,532)
.. (348,532)
.. controls (422,532) and (480,474)
.. (480,400)
.. controls (480,326) and (422,268)
.. (348,268)
.. controls (274,268) and (216,326)
.. (216,400)
-- cycle) ;
endchar;

beginchar (243,808*FS#,804*FS#,4*FS#);
"Ucircumflex";
setP ((0,664)
-- (264,400)
-- (0,136)
-- (140,-4)
-- (404,260)
-- (668,-4)
-- (808,136)
-- (544,400)
-- (808,664)
-- (668,804)
-- (404,540)
-- (140,804)
-- cycle) ;
endchar;

beginchar (244,626*FS#,526*FS#,0*FS#);
"Ugrave";
setP ((389,526)
-- (237,526)
-- (237,339)
-- (50,339)
-- (50,187)
-- (237,187)
-- (237,0)
-- (389,0)
-- (389,187)
-- (576,187)
-- (576,339)
-- (389,339)
-- cycle) ;
endchar;

beginchar (245,520*FS#,750*FS#,0*FS#);
"dotlessi";
setP ((230,750)
-- (230,539)
-- (80,539)
-- (80,484)
-- (230,484)
-- (230,0)
-- (290,0)
-- (290,484)
-- (440,484)
-- (440,539)
-- (290,539)
-- (290,750)
-- cycle) ;
endchar;

beginchar (246,1260*FS#,672*FS#,0*FS#);
"circumflex";
setP ((680,0)
-- (680,27)
.. controls (623,30) and (595,51)
.. (565,122)
.. controls (542,176) and (498,286)
.. (498,454)
.. controls (498,500) and (499,580)
.. (519,643)
.. controls (480,664) and (417,672)
.. (355,672)
.. controls (293,672) and (230,664)
.. (191,643)
.. controls (211,580) and (212,500)
.. (212,454)
.. controls (212,286) and (168,176)
.. (145,122)
.. controls (115,51) and (87,30)
.. (30,27)
-- (30,0)
-- cycle) ;
setP ((713,0)
-- (1230,0)
-- (1230,21)
.. controls (1185,24) and (1162,41)
.. (1139,97)
.. controls (1120,140) and (1085,227)
.. (1085,361)
.. controls (1085,397) and (1086,461)
.. (1102,511)
.. controls (1071,528) and (1021,534)
.. (972,534)
.. controls (922,534) and (872,528)
.. (841,511)
.. controls (857,461) and (858,397)
.. (858,361)
.. controls (858,227) and (823,140)
.. (805,97)
.. controls (781,41) and (759,24)
.. (713,21)
-- cycle) ;
endchar;

beginchar (247,510*FS#,750*FS#,0*FS#);
"tilde";
setP ((30,400)
-- (255,50)
-- (480,400)
-- (255,750)
-- cycle) ;
setP ((453,410)
-- (337,410)
-- (285,670)
-- (287,672)
-- cycle) ;
setP ((317,410)
-- (193,410)
-- (254,724)
-- (256,724)
-- cycle) ;
setP ((173,410)
-- (57,410)
-- (223,672)
-- (225,670)
-- cycle) ;
setP ((337,390)
-- (453,390)
-- (287,128)
-- (285,130)
-- cycle) ;
setP ((193,390)
-- (317,390)
-- (256,76)
-- (254,76)
-- cycle) ;
setP ((57,390)
-- (173,390)
-- (225,130)
-- (223,128)
-- cycle) ;
endchar;

beginchar (248,914*FS#,750*FS#,0*FS#);
"macron";
setP ((780,50)
-- (780,610)
-- (714,610)
.. controls (706,696) and (650,750)
.. (579,750)
.. controls (528,750) and (479,721)
.. (456,674)
.. controls (430,723) and (384,750)
.. (335,750)
.. controls (262,750) and (195,689)
.. (195,610)
-- (195,50)
-- (30,50)
-- (30,0)
-- (884,0)
-- (884,50)
-- cycle) ;
setP ((618,610)
-- (618,50)
-- (538,50)
-- (538,610)
-- (472,610)
.. controls (472,661) and (518,720)
.. (579,720)
.. controls (634,720) and (678,670)
.. (684,610)
-- cycle) ;
setP ((376,610)
-- (376,50)
-- (225,50)
-- (225,610)
.. controls (225,661) and (271,720)
.. (332,720)
.. controls (390,720) and (436,670)
.. (442,610)
-- cycle) ;
endchar;

beginchar (249,890*FS#,700*FS#,0*FS#);
"breve";
setP ((780,260)
-- (730,260)
-- (730,700)
-- (650,700)
-- (650,260)
-- (600,260)
-- (600,440)
-- (410,260)
-- (410,440)
-- (220,260)
-- (220,440)
-- (30,260)
-- (30,0)
-- (860,0)
-- (860,700)
-- (780,700)
-- cycle) ;
endchar;

beginchar (250,1042*FS#,280*FS#,0*FS#);
"dotaccent";
setP ((556,245)
-- (385,245)
-- (374,280)
-- (227,280)
-- (158,98)
-- (30,98)
-- (80,0)
-- (976,0)
-- (1012,98)
-- (758,98)
-- (732,181)
-- (576,181)
-- cycle) ;
setP ((364,215)
-- (539,215)
-- (558,151)
-- (708,151)
-- (725,98)
-- (191,98)
-- (249,250)
-- (352,250)
-- cycle) ;
setP ((514,151)
-- (506,181)
-- (377,181)
-- (387,151)
-- cycle) ;
setP ((269,211)
.. controls (269,199) and (279,189)
.. (291,189)
.. controls (304,189) and (314,199)
.. (314,211)
.. controls (314,224) and (304,234)
.. (291,234)
.. controls (279,234) and (269,224)
.. (269,211)
-- cycle) ;
endchar;

beginchar (251,852*FS#,677*FS#,0*FS#);
"ring";
setP ((447,408)
-- (546,507)
-- (674,380)
-- (822,529)
-- (674,677)
-- (426,430)
-- (178,677)
-- (30,529)
-- (178,380)
-- (306,507)
-- (405,409)
-- (141,144)
-- (162,123)
-- (426,387)
-- (691,123)
-- (712,144)
-- cycle) ;
setP ((179,635)
-- (285,529)
-- (179,423)
-- (73,529)
-- cycle) ;
endchar;

beginchar (252,946*FS#,857*FS#,58*FS#);
"cedilla";
setP ((702,-58)
.. controls (736,-58) and (742,-50)
.. (753,-18)
-- (931,539)
.. controls (939,563) and (946,593)
.. (946,619)
.. controls (946,659) and (909,700)
.. (867,718)
-- (581,837)
.. controls (553,849) and (513,857)
.. (473,857)
.. controls (433,857) and (393,849)
.. (366,837)
-- (79,718)
.. controls (38,700) and (0,659)
.. (0,619)
.. controls (0,593) and (7,563)
.. (15,539)
-- (193,-18)
.. controls (205,-50) and (210,-58)
.. (245,-58)
-- cycle) ;
endchar;

beginchar (253,1154*FS#,899*FS#,100*FS#);
"hungarumlaut";
setP ((52,899)
.. controls (0,899) and (-13,876)
.. (12,830)
-- (537,-66)
.. controls (563,-111) and (591,-111)
.. (617,-66)
-- (1142,830)
.. controls (1167,876) and (1154,899)
.. (1102,899)
-- cycle) ;
endchar;

beginchar (254,1072*FS#,919*FS#,121*FS#);
"ogonek";
setP ((0,-74)
.. controls (0,-124) and (21,-130)
.. (58,-112)
-- (1044,374)
.. controls (1082,393) and (1083,413)
.. (1044,432)
-- (58,910)
.. controls (21,928) and (0,922)
.. (0,872)
-- cycle) ;
endchar;
endinput;
%</charsMF|charsMP>
